<?php
/**
 * stanislav.elbl, 24.02.2016
 */

namespace RonPortal\Editace;

use Exception;
use Ron\DateUtils;
use Ron\DB\Database;
use Ron\DB\DBException;
use Ron\MessageManager;
use Ron\MVC\HttpController;
use Ron\MVC\Redirect;
use Ron\TextManager;
use RonPortal\NeniPravoException;
use RonPortal\XML\RonPortalXMLForm;

class PodleKalendareController extends HttpController
{
    /** @var  Database */
    private $database;

    /**
     * PodleKalendareController constructor.
     * @param Database $database
     */
    public function __construct(Database $database)
    {
        $this->database = $database;
    }


    /**
     * @throws DBException
     */
    public function vlozPodleKalendare()
    {
        $f = new PodleKalendareFormular($this ->database);
        $f ->nactiData($_POST['idpp'], null);

        try {
            $f ->nactiDataPodlePost();

            if (!EditaceDneUtils::jePravoEditovatDen($this ->database, $f ->pp, $f ->datumOd, $f ->datumDo)) {
                throw new NeniPravoException();
            }

            EditaceUtils::editaceDochazkyEvent($this ->database, $f ->pp, $f ->datumOd, 'before');

            $f ->provedVlozeni();

            EditaceUtils::editaceDochazkyEvent($this ->database, $f ->pp, $f ->datumOd, 'after');

            return RonPortalXMLForm::$eventRedirect
                ?: new Redirect(null, '?menuid=zpracovanadochazka&idpp=' . $f ->pp ->idPP . '&obdobi=' . DateUtils::dateToUrlString($f ->obdobi ->zacatek));
        } catch (Exception $e) {
            MessageManager::addErrorMessage($e);
            return $f;
        }
    }


    /**
     * @throws DBException
     * @throws Exception
     */
    public function handleAction($action)
    {
        TextManager::getInstance() ->loadStrings('dochazka.ini');

        if ( isset($_POST['action'])  &&  $_POST['action'] === 'vlozpodlekalendare' ) {
            return $this ->vlozPodleKalendare();
        }

        $f = new PodleKalendareFormular($this ->database);

        $datum = isset($_GET['datum'])
            ? DateUtils::urlStringToDate($_GET['datum'])
            : null;

        $datumDo = isset($_GET['datumdo'])
            ? DateUtils::urlStringToDate($_GET['datumdo'])
            : null;

        $f ->nactiData((int)$_GET['idpp'], $datum, $datumDo);
        return $f;
    }

}

return new PodleKalendareController($this ->database);
