<?php
/**
 * UTF8
 * Roman.Szablatura RON Software 15.08.2019
 */

namespace Ron\RonPortal\Notifikace;


use Ron\Browser;
use Ron\BrowserField;
use Ron\Controls\ComboBox;
use Ron\DB\Database;
use Ron\DB\SqlStatement;
use Ron\GuiUtils;
use Ron\RonPortal\RonPortalFilterForm;


require_once 'ron/browser.php';
require_once 'ron/guiutils.php';
require_once 'adsapp/ronportalfilter.php';


/**
 * Class NotifikaceFilterForm
 * @package Ron\RonPortal\Notifikace
 */
class NotifikaceFilterForm extends RonPortalFilterForm
{


    /**
     * NotifikaceFilterForm constructor.
     * @param Database $database
     * @param string $action
     * @param bool $useGet
     */
    public function __construct(Database $database, string $action, bool $useGet = false)
    {
        parent::__construct($database, $action, $useGet);

        $this->f_formaction = "?menuid=notifikace";
        $this->f_classname = 'filtercontainer leftcaptions';
    }



    /**
     * @throws \Ron\DB\DBException
     */
    public function typNotifikace()
    {
        echo '<div class="filterrow">';
        echo '<span class="filtercaption">';
            GuiUtils::renderCheckbox('jenTypNotifikace', \Ron\ronText('typ_notifikace'). '&nbsp;&nbsp;', $_SESSION['jenTypNotifikace'],
                'onClick="submit()"');
        echo '</span>';

        $sql = "Select Kod, Popis " .
            "From TypNotifikace Where Exists (Select *) ORDER BY Popis";

        $combo = new ComboBox('filtrTypNotifikace');
        $combo->className = 'app_combo adsfilterforminput_full';
        $combo->htmlParams = 'onChange="if (jenZdaPrecteno.checked) submit();"';
        $combo->dataTypeComparison = false;
        $combo->showCode = 0;
        $combo->loadData($this->database, $sql, $_SESSION['filtrTypNotifikace']);
        $combo->render();
        echo '</div>';
    }


    public function loadTypNotifikace()
    {
        if (isset($_POST['adsfilterform'])){
            $_SESSION['jenTypNotifikace'] = isset($_POST['jenTypNotifikace']);
            $_SESSION['filtrTypNotifikace'] = ($_POST['filtrTypNotifikace']);
        }
    }


    /**
     * @throws \Exception
     */
    function loadData()
    {
        parent::loadData();

        $this->loadTypNotifikace();
    }


    /**
     * @throws \Ron\DB\DBException
     */
    function renderFilters()
    {
        $this->typNotifikace();
    }
}



/**
 * Class DetailNotifikaceField
 * @package Ron\RonPortal\Notifikace
 */
class DetailNotifikaceField extends BrowserField
{

    /**
     * DetailNotifikaceField constructor.
     * @param Database $database
     * @param null $options
     */
    public function __construct($database = null, $options = null)
    {
        parent::__construct($database, $options);
    }

    /**
     * @param mixed $value
     * @param int $rowNumber
     * @param string $recordId
     * @param array $rowData
     * @return string
     */
    function getViewText($value, $rowNumber, $recordId, $rowData)
    {
        $result = "";

        $result .= "<a href='?menuid=notifikace&action=detailnotifikace&record=" . $rowData[0] . "'>";
        $result .= \Ron\ronText('detail');
        $result .= "</a>";

        return $result;
    }
}




/**
 * Class NotifikaceBrowser
 * @package Ron\RonPortal\Notifikace
 */
class NotifikaceBrowser extends Browser
{
    /** @var Database $database */
    public $database;

    /** @var NotifikaceFilterForm $filter */
    public $filter;

    /**
     * NotifikaceBrowser constructor.
     * @param Database $database
     * @throws \Exception
     */
    public function __construct($database)
    {

        parent::__construct($database);

        $this->database = $database;

        //TODO implementovat filtr na prectene / neprectene
        //TODO implementovat filtr dle typu notifikace


        $this->sqlSelectPart =
            'N.ID, N.Typ, PoradiGenerovani, N.PP_CiloveRC, N.PP_CiloveOsobniCislo, N.PP_CiloveDatumNastupu, ' .                       //0..5
            'N.PP_ZdrojoveRC, N.PP_ZdrojoveOsobniCislo, N.PP_ZdrojoveDatumNastupu,' .                                                   //6..8
            'N.PrectenoIntraweb, N.TextNotifikace, N.Insert_UserName, N.Insert_Timestamp, N.Update_UserName, N.Update_Timestamp, ' .      //9..14
            'TypNotifikace.Popis';                                                                                                  //15..

        $this->sqlFromPart = 'Notifikace N LEFT JOIN TypNotifikace ON (TypNotifikace.Kod = N.Typ)';


        $this->filter = new NotifikaceFilterForm($this->database, "");
        $this->filter->loadData();

        //TODO sloupce viz: datum / typ / přečteno / detail / od koho
        $this->addField([BROWSER_FIELD_SQL_INDEX => 12, BROWSER_FIELD_SQL_NAME => 'Insert_Timestamp', BROWSER_FIELD_FORMAT => 'date',
                    BROWSER_FIELD_HEADER_TEXT => 'vlozeno']);

        $this->addField([BROWSER_FIELD_SQL_INDEX => 15, BROWSER_FIELD_SQL_NAME => 'TypNotifikace.Popis', BROWSER_FIELD_ORDERING => 1,
                    BROWSER_FIELD_ALIGN => 'center', BROWSER_FIELD_HEADER_TEXT => 'typ']);

        $this->addField([BROWSER_FIELD_SQL_INDEX => 9, BROWSER_FIELD_SQL_NAME => 'N.PrectenoIntraweb', BROWSER_FIELD_ORDERING => 1,
                    BROWSER_FIELD_ALIGN => 'center', BROWSER_FIELD_FORMAT => 'date', BROWSER_FIELD_HEADER_TEXT => 'precteno']);

        $this->addField(new DetailNotifikaceField($this->database));


        //TODO vlozeno kdy (kym)
        //TODO aktualizovano kdy (kym)

    }

    /**
     *
     */
    function renderFilter()
    {
        $this->filter->render();
        parent::renderFilter();
    }


    /**
     * @return \Ron\DB\SqlStatement|string
     */
    function getSQLFilter()
    {
        $result = "";
        $params = $this->database->createParameters();

        $result .= "N.PrectenoIntraweb IS NULL";

        if ($_SESSION['jenZdaPrecteno']){
            if ($_SESSION['filtrZdaPrecteno'] == 1){
            } elseif ($_SESSION['filtrZdaPrecteno'] == 2){
                $result .= "N.PrectenoIntraweb IS NULL";
            }
        }


        return new SqlStatement($result, $params);
    }
}
