<?php
/** UTF8
 * pavel.rudol, 28.1.2015
 * Seznam událostí provozního deníku. 
 * Typ rozdělení se řídí nastaveným typem rozdělení v nastavení práv u práva: pr_denik_read
 * !Pozor: Stejný typ rozdělení musí být nastaven i u práva: pr_denik_write
 */

namespace Ron\RonPortal;

use Exception;
use Ron\Browser;
use Ron\BrowserField;
use Ron\Controls\ComboBox;
use Ron\DateUtils;
use Ron\DB\Database;
use Ron\DB\DBUtils;
use Ron\GuiUtils;
use Ron\MessageManager;
use Ron\Personalistika\ProvozniDenikController;
use Ron\StringUtils;
use RonPortal\RonPortalSession;
use RonPortal\RonPortalSettings;
use function Ron\ronText;

require_once('ron/browser.php');


class ProvozniDenikFilterForm extends \RonPortal\Controls\RonPortalFilterForm
{
    var $muzeVkladat; //uzivatel ma pravo vkladat nove zaznamy

    var $rozdeleniPK;

    /**
     * @param Database $database
     * @param PravaNaOsoby $prava
     * @param bool $muzeVkladat
     * @param int $typRozdeleni
     * @param string $rozdeleni
     */
    function __construct($database, $prava, $muzeVkladat, $typRozdeleni, $rozdeleni)
    {
        parent::__construct($database, 'provoznidenik');

        $this->muzeVkladat = $muzeVkladat;

        $this->f_classname = 'filtercontainer leftcaptions';

        $this->nastavDatumOdDo(true, false, ronText('datum_udalosti') . ' ' . ronText('Od'));

        if (isset($rozdeleni)) {
            $this->rozdeleniPK = $rozdeleni;
            $this->nastavRozdeleni(true, $typRozdeleni,0,"Kod = '" . $database->addSlashes($rozdeleni)."'",true);
        }
        else {
            $this->nastavRozdeleni(true, $typRozdeleni, 2, '', true);
        }
        $this->showVcetnePodrizenychRozdeleni = false;
        $this->f_pravarozdeleni = $prava;
    }


    /**
     * @throws Exception
     */
    function renderTypUdalosti()
    {
        echo '<br />';
        
        echo '<DIV class="filterrow">';
        
        // checkbox "Jen aktivni"
        echo '<SPAN class="filtercaption">';
        GuiUtils::renderCheckbox('jenAktivniUdalostPD',
            ronText('jen_aktivni_udalost') . '&nbsp;&nbsp;', $_SESSION['jenAktivniUdalostPD'],
            'onClick="submit()"');

        echo '</SPAN>';
        
        echo "</DIV>\n";
        
        echo '<DIV class="filterrow">';

        //echo '<TR><TD>';
        // checkbox "Jen udalost"
        echo '<SPAN class="filtercaption">';
        GuiUtils::renderCheckbox('jenUdalostPD',
            ronText('jen_udalost') . '&nbsp;&nbsp;', $_SESSION['jenUdalostPD'],
            'onClick="submit()"');

        echo '</SPAN>';
        //echo '</TD><TD>';

        // combobox pro vyber
        $sql =
            'SELECT Kod, Popis FROM TypUdalostiPD ';        

        if ($_SESSION['jenAktivniUdalostPD']) {
            $sql .= 'WHERE Aktivni = 1';
        }
        
        $sql .=
            ' ORDER BY Popis';

        // vyber typu udalosti podle popisu
        $combo = new ComboBox('udalostPD');
        $combo->className = 'app_combo adsfilterforminput_full';
        $combo ->emptyRow = ' ' ;
        $combo->loadData($this ->database, $sql, $_SESSION['udalostPD']);
        $combo ->htmlParams = 'onChange="if (jenUdalostPD.checked) submit();"';
        $combo->render();
        
        //echo '</TD></TR>';
        echo "</DIV>\n";
        echo "<BR />";
    }


    /**
     * @throws Exception
     */
    function renderFilters()
    {
        parent::renderFilters(); // datum
       
        $this->renderTypUdalosti();

        if (RonPortalSettings::getIntValue('pd_pouzit_rozdeleni_kapacity') && isset($this->rozdeleniPK)) {
            echo '<br /> <strong>';
            echo sprintf(ronText('typ_rozdeleni'),
                DBUtils::getSqlValue($this->database, 'SELECT Popis FROM TypRozdeleni WHERE Kod = ' . (int)$this->f_typrozdeleni),
                DBUtils::getSqlValue($this->database, "SELECT Popis FROM Rozdeleni WHERE Kod = '" . $this->rozdeleniPK . "' AND KodTypuRozdeleni = " .(int)$this->f_typrozdeleni));
            echo '</strong><br />';
        }

        if ($this->muzeVkladat) {
            echo '<BR />';
            echo '<A class="text_link" href="?menuid=provoznidenik&action=denikform&formaction=new">' . ronText('nova_udalost') . '</A>';
            echo '<BR />';
        }
    }
}

class EditaceUdalostiField extends BrowserField
{
//    var $f_MuzeEditovat;
//    var $f_ZpetnaEditaceSekund;
    /** @var PravaNaOsoby */
    var $prava;

    /** @var Database */
    var $database;

    var $rozdeleniPK;

    /**
     * @param PravaNaOsoby $prava
     * @param Database $database
     * @param string $rozdeleniPK
     */
    function __construct($prava, $database, $rozdeleniPK)
    {
        parent::__construct($database);

//        $this->f_MuzeEditovat = $lzeEditovat;
//        $this->f_ZpetnaEditaceSekund = $editovatSekund;
        $this->prava = $prava;
        $this->rozdeleniPK = $rozdeleniPK;
        $this->type = 'text';
        $this->align = 'left';
    }

    /**
     * @param mixed $value
     * @param int $rowNumber
     * @param string $recordId
     * @param array $rowData
     * @return string
     * @throws Exception
     */
    function getViewText($value, $rowNumber, $recordId, $rowData)
    {
        $result = '';

        if ($this->prava->priznak
            && (($this->prava->priznak2 == 0) || ($this->database->stringToTimestamp($rowData[1]) > DateUtils::incMinute(time(),- $this->prava->priznak2)))
            && (($this->prava->lzeZobrazitRC($rowData[9], time(), time()))
                && ((($this->prava->jePravoNaRozdeleni($this->prava->typRozdeleni,$rowData[5]))) ||
                    ($this->rozdeleniPK == $rowData[5] && $rowData[9] == User::getRC()))
            )
        ) {
            $result = '<a href="?menuid=provoznidenik&action=denikform&formaction=edit&record=' . $recordId . '">';

            $result .= ronText('editovat');
            
            //$result .= $this->f_prava->LzeZobrazitRC($rowdata[9]).'-'.$rowdata[9];

            $result .= '</a>';
        }
        return $result;
    }
}

class ProvozniDenikBrowser extends Browser {
    
    var $pravaZobrazit;
    var $pravaZapsat;

    var $typRozdeleni;
    var $rozdeleni;

    /** @var  ProvozniDenikFilterForm */
    var $filterForm;

    /**
     * ProvozniDenikBrowser constructor.
     * @param Database $database
     */
    function __construct($database) {
        parent::__construct($database);
        
        $this->pravaZobrazit = Prava::vratPrava('pr_denik_read');
        $this->pravaZapsat = Prava::vratPrava('pr_denik_write');
        Prava::nastavObdobiProPrava(time(),time());
        $this->title = ronText('provozni_denik');
        $this->code = 'browserprovoznidenik';
        $this->tableId = 'browserprovoznidenik';
        
        $this->sqlSelectPart =
            'ProvozniDenik.ID, ProvozniDenik.DatumCas, ProvozniDenik.Popis, ProvozniDenik.TypUdalosti, TypUdalostiPD.Popis,'. // 0 - 4
            'ProvozniDenik.KodRozdeleni, Rozdeleni.Popis,' . // 5 - 6
            'Osoba.Jmeno, Osoba.Prijmeni, Osoba.RC, ' . // 7 - 9
            $database ->castWideMemo('ProvozniDenik.Poznamka') . ', ' . // 10
            '(SELECT MAX(OsobniCislo) FROM PracovniPomer WHERE PracovniPomer.RC = ProvozniDenik.RC ' .
            '   AND PracovniPomer.DatumNastupu <= ' . $database ->dateToString(date(time())) .
            '   AND (PracovniPomer.DatumUkonceni >= ' . $database ->dateToString(date(time())) . ' OR PracovniPomer.DatumUkonceni IS NULL) ' .
            '   AND NOT EXISTS(SELECT RC FROM PracovniPomer PP WHERE PP.RC = PracovniPomer.RC AND PP.DatumNastupu > PracovniPomer.DatumNastupu '.
            '     AND PP.DatumNastupu <= ' . $database ->dateToString(date(time())) .
            '     AND (PP.DatumUkonceni >= ' . $database ->dateToString(date(time())) . ' OR PP.DatumUkonceni IS NULL) )) as OsobniCislo'; //11
        
        $this->sqlFromPart =
                'ProvozniDenik JOIN TypUdalostiPD ON (TypUdalostiPD.Kod = ProvozniDenik.TypUdalosti)'.
                'LEFT OUTER JOIN Rozdeleni ON ((Rozdeleni.KodTypuRozdeleni = ProvozniDenik.KodTypuRozdeleni) AND (Rozdeleni.Kod = ProvozniDenik.KodRozdeleni))'.
                'LEFT OUTER JOIN Osoba ON (Osoba.RC = ProvozniDenik.RC)';
        
        
        $this->defaultSort = 1;
        $this->primaryField = 0;
        
        $this->browserUrl = '?menuid=provoznidenik&';

        $this ->addFields( [
                [BROWSER_FIELD_SQL_INDEX => 1, 'sqlFieldName' => 'ProvozniDenik.DatumCas',      BROWSER_FIELD_HEADER_TEXT => 'Date',    'format' => 'date', 'ordering' => 1, 'f_align' => 'right'],
                [BROWSER_FIELD_SQL_INDEX => 1, 'sqlFieldName' => 'ProvozniDenik.DatumCas',      BROWSER_FIELD_HEADER_TEXT => 'Cas',     'format' => 'time', 'ordering' => 1, 'f_align' => 'right'],
                [BROWSER_FIELD_SQL_INDEX => 5, 'sqlFieldName' => 'ProvozniDenik.KodRozdeleni',  BROWSER_FIELD_HEADER_TEXT => 'Kod',     'ordering' => 1],
                [BROWSER_FIELD_SQL_INDEX => 6, 'sqlFieldName' => 'Rozdeleni.Popis',             BROWSER_FIELD_HEADER_TEXT => 'rozdeleni', 'ordering' => 1],
                [BROWSER_FIELD_SQL_INDEX => 4, 'sqlFieldName' => 'TypUdalostiPD.Popis',         BROWSER_FIELD_HEADER_TEXT => 'popis_typu_udalosti',    'ordering' => 1],
                [BROWSER_FIELD_SQL_INDEX => 8, 'sqlFieldName' => 'Osoba.Prijmeni',              BROWSER_FIELD_HEADER_TEXT => 'Prijmeni',  'ordering' => 1],
                [BROWSER_FIELD_SQL_INDEX => 7, 'sqlFieldName' => 'Osoba.Jmeno',                 BROWSER_FIELD_HEADER_TEXT => 'Jmeno',     'ordering' => 1],
                [BROWSER_FIELD_SQL_INDEX => 11, 'sqlFieldName' => 'OsobniCislo',                BROWSER_FIELD_HEADER_TEXT => 'Osobni_cislo',    'ordering' => 1, 'f_classname' => 'pd_osobnicislo'],
        ]);



        $this->rozdeleni = null;

        if (RonPortalSettings::getIntValue('pd_pouzit_rozdeleni_kapacity')) {
            try {
                $this->rozdeleni = ProvozniDenikController::vratRozdeleniPlanovaniKapacit($database, User::getRC(), time());
            } catch (Exception $e) {
                $this->rozdeleni = null;
                MessageManager::addInfoMessage($e->getMessage());
            }
        }

        if (RonPortalSettings::getIntValue('pd_pouzit_rozdeleni_kapacity') && (isset($this->rozdeleni))) {
            $this->typRozdeleni = RonPortalSettings::getIntValue(RonPortalSettings::KAPACITY_TYP_ROZDELENI);
        }
        else {
            $this->typRozdeleni = $this->pravaZobrazit->typRozdeleni;
        }
        $this->addField(new EditaceUdalostiField($this->pravaZapsat, $database, $this->rozdeleni));
    }


    /**
     * @param string $sqlFilter
     * @throws Exception
     */
    function load($sqlFilter = '')
    {
        if (isset($_POST['adsfilterform'])) {
            $_SESSION['jenAktivniUdalostPD'] = isset($_POST['jenAktivniUdalostPD']);

            $_SESSION['jenUdalostPD'] = isset($_POST['jenUdalostPD']);

            $_SESSION['udalostPD'] = $_POST['udalostPD'];
        }

        $this ->filterForm = new ProvozniDenikFilterForm($this ->database, $this->pravaZobrazit,$this->pravaZapsat->jsouNejakePrava(),$this->typRozdeleni, $this->rozdeleni);
        $this ->filterForm ->loadData();

        parent::load($sqlFilter);
    }

    function renderFilter()
    {
        $this ->filterForm ->render();
    }

    function getSQLFilter()
    {
        if (RonPortalSettings::getIntValue('pd_pouzit_rozdeleni_kapacity') && isset($this->rozdeleni)) {

            //rozdělení bude zobrazeno podle přiřazeného rozdeleni v plánování kapacit
            $result = "
                 EXISTS(SELECT Rozdeleni FROM PlanovaniKapacit WHERE PlanovaniKapacit.RC = '" . $this->database->addSlashes(User::getRC()) . "'
                        AND PlanovaniKapacit.KodTypuRozdeleni = " . (int)RonPortalSettings::getIntValue(RonPortalSettings::KAPACITY_TYP_ROZDELENI) . "
                        AND PlanovaniKapacit.Rozdeleni = ProvozniDenik.KodRozdeleni
                        AND PlanovaniKapacit.Datum = " . $this->database->timestampToString(DateUtils::startOfTheDay(time())) . ")";

        }
        else {

            if ($this->pravaZobrazit->jsouNejakePrava()) {
                $result = "((" . $this->pravaZobrazit->sqlfiltrRozdeleni(RonPortalSession::getDatumOd(), RonPortalSession::getDatumDo()) . ") OR (ProvozniDenik.RC = '" . $this->database->addSlashes(User::getRC()) . "'))";
            } else {
                if ($this->pravaZapsat->priznak) {
                    $result = "(ProvozniDenik.RC = '" . $this->database->addSlashes(User::getRC()) . "')";

                    $result .= ' AND (' . $this->pravaZapsat->sqlfiltrRozdeleni(RonPortalSession::getDatumOd(), RonPortalSession::getDatumDo()) . ')';

                    if ($this->pravaZapsat->priznak2 > 0) {
                        $result .= " AND (ProvozniDenik.DatumCas >= " . $this->database->timestampToString(DateUtils::incMinute(time(), $this->pravaZapsat->priznak2)) . ")";
                    }
                } else {
                    $result = '1 = 0';
                }
            }
        }

        if ($_SESSION['jenAktivniUdalostPD']) {
            if ($result) {
                $result .= ' AND';
            }
            $result .= ' TypUdalostiPD.Aktivni = 1';
        }
                
        if ($_SESSION['jenUdalostPD']) {
            if ($result) {
                $result .= ' AND';
            }
            $result .= " TypUdalostiPD.Kod = '" . $this ->database ->addSlashes($_SESSION['udalostPD']) . "'";
        }
        
        if (RonPortalSession::rozdeleni($this->filterForm->f_typrozdeleni)) {
            if ($result) {
                $result .= ' AND';
            }
            $result .= ' ProvozniDenik.KodTypuRozdeleni = '. (int)$this->pravaZobrazit->typRozdeleni .
                " AND ProvozniDenik.KodRozdeleni = '" . $this ->database ->addSlashes(RonPortalSession::rozdeleni($this->filterForm->f_typrozdeleni)) . "'";
        }
        
        if (RonPortalSession::getFiltrovatDatum() || (!isset($_POST['adsfilterform']))) {
            if ($result) {
                $result .= ' AND';
            }
            $result .= ' ProvozniDenik.DatumCas >= ' . $this ->database ->timestampToString(RonPortalSession::getDatumOd()) .
                ' AND ProvozniDenik.DatumCas < ' . $this ->database ->timestampToString(DateUtils::incDay(RonPortalSession::getDatumDo(),1));
        }
        
        return $result;
    }

    function renderLine($values, $className, $rowNumber, $edit = false)
    {
        parent::renderLine($values, $className, $rowNumber, $edit);

        if ($values[10] || $values[2]) {
            // podrobny popis
            echo "<tr class='$className'>";
            echo '<td></td><td colspan="' . ($this->columnCount - 1) . '">';
            if ($values[2]) {
                echo '<span id="pd_popis">' . ronText('popis') . ': ' . StringUtils::htmlTextConvert($values[2]) . '</span>';
            }
            if ($values[10]) {
                echo '<span class="browserpoznamka pd_poznamka">' . ronText('text_cinnosti') . ': ' . StringUtils::htmlTextConvert($values[10]) . '</span></td>';
            }
            echo '</tr>';
        }
    }
}


