<?php
/**
 * stanislav.elbl, 28.02.2016
 */

namespace Ron\Personalistika;

use Ron\DateUtils;
use Ron\DB\Database;
use RonPortal\RonPortalDBRecord;


/**
 * Class VzdelaniOsoby
 * @package Ron\Personalistika
 * @deprecated
 */
class VzdelaniOsoby extends \RonPortal\Zamestnanci\VzdelaniOsoby
{
    /**
     * @param Database  $database
     * @param string    $rc
     * @param string    $tableName
     * @param int $index
     * @param object|string $logDescription
     * @return bool|int
     * @throws \Exception
     * @throws \Ron\DB\DBException
     */
    public static function ulozVzdelani($database, $rc, $tableName, $index = null, $logDescription = 'VzdelaniOsoby')
    {
        $insert = false;
        $loaded = false;

        $vzdelaniRec = new RonPortalDBRecord($database, $tableName, $logDescription);

        $vzdelaniRec->addField('RC','',true, 15);
        $vzdelaniRec->addField('KodVzdelani', 'int', true);
        $vzdelaniRec->addField('OborVzdelani','', true, 10);
        $vzdelaniRec->addField('DatumUkonceni', 'timestamp', true);
        $vzdelaniRec->addField('Skola', '', false, 10);
        $vzdelaniRec->addField('DatumOd', 'timestamp', false);
        $vzdelaniRec->addField('DatumDo', 'timestamp', false);
        $vzdelaniRec->addField('Zamereni', '', false, 40);
        $vzdelaniRec->addField('VzdelaniUkonceno', 'int', false);

        $vzdelaniRec->where =
            self::getWhereCondition($rc, $database, $index);

        //pri vkladani noveho zaznamu neexistuji puvodni hodnoty, provadi se jen insert a nenacita se tedy zaznam z DB
        if ($vzdelaniRec->where == '') {
            $vzdelaniRec->findFieldByName('RC')->setNewValue($rc);
            $insert = true;
        }
        else {
            $loaded = $vzdelaniRec->loadRecord();
        }

        self::nactiPost($vzdelaniRec, $index);

        //pokud nejsou zadana povinna pole vraci -1
        if (($vzdelaniRec['KodVzdelani'] == null) || ($vzdelaniRec['OborVzdelani'] == null) || ($vzdelaniRec['DatumUkonceni'] == null)) {
            return -1;
        }

        //zaznam o vzdelani jeste u osoby neexistuje, nebo ve formulari nebyl nacten zaznam pro editaci, provadi se vlozeni
        if ($insert) {
            $vzdelaniRec->insertRecord();
            return true;
        }

        if ($loaded === false) {
            throw new \Exception('Chyba pri nacitani zaznamu vzdelani.');
        }
        if (!$vzdelaniRec->isChanged()) {
            return 0;
        }
        if ($loaded) {
            return $vzdelaniRec->updateRecord();
        }

        return 0;
    }

    /**
     * @param RonPortalDBRecord $rec
     * @param int $index
     */
    private static function nactiPost($rec, $index)
    {
        $poradi = '';

        if (!is_null($index)) {
            $poradi = '_' . $index;
        }

        $rec->findFieldByName('KodVzdelani')->setNewValue((int)$_POST['vzdelani_kod'.$poradi]);
        $rec->findFieldByName('OborVzdelani')->setNewValue($_POST['vzdelani_obor'.$poradi]);

        if ($_POST['vzdelani_datum_ukonceni'.$poradi] != '') {
            $rec->findFieldByName('DatumUkonceni')->setNewValue(DateUtils::dateStringToTimestamp($_POST['vzdelani_datum_ukonceni' . $poradi]));
        }
        if ($_POST['vzdelani_skola'.$poradi] != '') {
            $rec->findFieldByName('Skola')->setNewValue($_POST['vzdelani_skola' . $poradi]);
        }

        if ($_POST['vzdelani_datum_od'.$poradi] != '') {
            $rec->findFieldByName('DatumOd')->setNewValue(DateUtils::dateStringToTimestamp($_POST['vzdelani_datum_od' . $poradi]));
        }

        if ($_POST['vzdelani_datum_do' . $poradi] != '') {
            $rec->findFieldByName('DatumDo')->setNewValue(DateUtils::dateStringToTimestamp($_POST['vzdelani_datum_do' . $poradi]));
        }
        $rec->findFieldByName('Zamereni')->setNewValue($_POST['vzdelani_zamereni'.$poradi]);
        $rec->findFieldByName('VzdelaniUkonceno')->setNewValue((int)$_POST['vzdelani_ukonceno'.$poradi]);
    }

    /**
     * @param string $rc
     * @param Database $database
     * @param int $index
     * @return string
     */
    private static function getWhereCondition($rc, $database, $index)
    {
        $poradi = '';

        if (!is_null($index)) {
            $poradi = '_' . $index;
        }

        if ((isset($_POST['vzdelani_kod_puvodni'.$poradi]) && isset($_POST['vzdelani_obor_puvodni'.$poradi]) && isset($_POST['vzdelani_datum_ukonceni_puvodni'.$poradi]))
            && (($_POST['vzdelani_kod_puvodni'.$poradi] != '') && ($_POST['vzdelani_obor_puvodni'.$poradi] != '') && ($_POST['vzdelani_datum_ukonceni_puvodni'.$poradi] != ''))
        ) {
            return
                "RC = '" . $database->addSlashes($rc) . "'" .
                " AND KodVzdelani = " . (int)$_POST['vzdelani_kod_puvodni' . $poradi] .
                " AND OborVzdelani = '" . $database->addSlashes($_POST['vzdelani_obor_puvodni' . $poradi]) . "'" .
                " AND DatumUkonceni = " . $database->timestampToString($_POST['vzdelani_datum_ukonceni_puvodni' . $poradi]);
        }

        return '';
    }
}
