<?php
/**
 * stanislav.elbl, 19.02.2021
 */

namespace Ron\MVC;

use Ron\KeyValuesArray;

class Model implements \ArrayAccess
{
    /** @var KeyValuesArray */
    private $data;

    /** @var ViewObject[] */
    private $viewObjects;

    /** @var Model $model   Globalni instance */
    protected static $model;


    public function __construct() {
        $this ->data = new KeyValuesArray();
        $this ->viewObjects = [];
    }

    /**
     * ArrayAccess
     * @param $offset
     * @return bool
     */
    public function offsetExists($offset): bool
    {
        return $this ->data ->offsetExists($offset);
    }

    /**
     * ArrayAccess
     * @param $offset
     * @return mixed
     */
    #[\ReturnTypeWillChange]    // kvuli podpore PHP 7 nelze prozatim nastavit typy
    public function offsetGet($offset)
    {
        return $this ->data ->offsetGet($offset);
    }

    /**
     * @param mixed $offset
     * @param mixed $value
     * @return void
     */
    public function offsetSet($offset, $value): void
    {
        $this ->data ->offsetSet($offset, $value);
    }

    /**
     * Offset to unset
     * @param mixed $offset
     * @return void
     */
    public function offsetUnset($offset): void
    {
        $this ->data ->offsetUnset($offset);
    }


    /**
     * @param string|null $key   Pokud neni zadano, vraci cele pole data, jinak vraci konkretni prvek
     * @return mixed
     */
    public function getData($key = null)
    {
        if (isset($key)) {
            if (isset($this ->data[$key])) {
                return $this ->data[$key];
            }

            return null;
        }

        return $this ->data;
    }


    /**
     * @return ViewObject[]
     */
    public function getViewObjects()
    {
        return $this->viewObjects;
    }


    /**
     * Vraci globalni instanci objektu Model
     * @return Model
     */
    public static function getInstance()
    {
        if (!self::$model) {
            self::$model = new Model();
        };

        return self::$model;
    }


    /**
     * Nastavi data (libovolna hodnota nebo objekt) pro zadany klic do globalniho objektu Model
     * @param string $key
     * @param mixed $value
     */
    public static function setData($key, $value)
    {
        self::getInstance() ->data ->setValue($key, $value);
    }

    /**
     * Prida data (libovolna hodnota nebo objekt) pro zadany klic do globalniho objektu Model
     * @param string $key
     * @param mixed $value
     */
    public static function addData($key, $value)
    {
        self::getInstance() ->data ->addValue($key, $value);
    }

    /**
     * Prida ViewObject do globalniho objektu Model
     * @param ViewObject $viewObject
     */
    public static function addViewObject($viewObject)
    {
        self::getInstance() ->viewObjects[] = $viewObject;
    }

}
