<?php

/**
 * Implementace filtru pro vyber variabilniho obdobi
 */

namespace Ronportal\Controls;

use Ron\DateUtils;
use Ron\DB\Database;
use Ron\MessageManager;
use Ron\TextManager;
use RonPortal\RonPortalSettings;

class FilterFormFilterVariabilni extends FilterFormFilter
{
    /** @var ComboBoxObdobi */
    protected $comboVariantni;

    /** @var int    Maximalni pocet zobrazenych zaznamu */
    protected $maximalniPocetObdobi = 0;

    /** @var int|null   Konec zvoleneho obdobi */
    protected $konecObdobi = null;


    public function __construct(RonPortalFilterForm $filterForm, string $name = 'variantni')
    {
        parent::__construct($name, FilterFormFilter::TYPE_OPTIONS);

        $this ->definesPeriod = true; // filtr omezuje obdobi pro prava a pro dalsi filtry (rozdeleni atd.)
        $this ->rowId = 'filterrow_variabilni';

        $this ->caption = TextManager::_('Variabilni_obdobi');
        $this ->sessionName = 'filtr' . $this ->name; // pro kompatibilitu

        $this ->maximalniPocetObdobi = RonPortalSettings::getIntValue('maximalnipocetobdobi');

        $this ->htmlAttributes = [
            'id' => 'adsfilterform_variabilni',
            'data-ron-autosubmit' => $filterForm ->autoSubmit ? '1' : '0'
        ];

    }


    /**
     * @param int|mixed $maximalniPocetObdobi
     * @return FilterFormFilterVariabilni
     */
    public function setMaximalniPocetObdobi($maximalniPocetObdobi)
    {
        $this->maximalniPocetObdobi = $maximalniPocetObdobi;
        return $this;
    }



    public function loadConfigurationItem($key, $value, $valueText)
    {
        switch ($key) {
            case 'maximalniPocetObdobi' :
                $this ->{$key} = (int)$value;
                break;

            default :
                parent::loadConfigurationItem($key, $value, $valueText);
        }
    }


    protected function loadSubmitedValue()
    {
        if (!parent::loadSubmitedValue()) {
            return false;
        }

        try {
            $obdobi = DateUtils::urlStringToDate($this ->value, true);
            $this ->value = $obdobi;
            return true;
        } catch (\Exception $e) {
            MessageManager::addErrorMessage($e ->getMessage());
            return false;
        }
    }


    public function load(Database $database)
    {
        parent::load($database);

        $this ->comboVariantni = new ComboBoxObdobi($this ->name);
        $this ->comboVariantni
            ->setClassName($this ->getCssClass())
            ->setHtmlParams($this ->htmlAttributes)
            ->setOrderBy($this ->optionsSqlOrder ?? ' PocatekObdobi DESC')
            ->setSqlFilter($this ->optionsSqlFilter);

        $this ->comboVariantni ->maximalniPocetObdobi = $this ->maximalniPocetObdobi;
        $this ->comboVariantni ->loadObdobi($database, '', true,
            false, false,
            $this ->value);
        //$this ->comboVariantni ->nastavSessionVariantni();

        $this ->value = $this ->comboVariantni ->pocatekObdobi;
        $this ->konecObdobi = $this ->comboVariantni ->konecObdobi;
    }


    public function getValue(?string $specification = null)
    {
        switch ($specification) {
            case 'datumOd' :
                return $this ->value;

            case 'konecObdobi' :
            case 'datumDo' :
                return $this ->konecObdobi;

            case 'popis' :
                return $this ->comboVariantni
                    ? $this ->comboVariantni ->popisObdobi
                    : null;
        }

        return parent::getValue($specification);
    }

    /*
    public function loadVariantni()
    {
        //HttpResponse::setCookieAndSession('ads_variantni', 'variantni', true, false); - bylo puvodne v appcontroller.LoadCookies()

        $obdobi = RonPortalSession::variantniObdobi(); // pouzije se, pokud neni zadano v GET/POST nebo je zadano chybne

        try {
            if (isset($_POST['variantni'])) {
                $obdobi = DateUtils::urlStringToDate($_POST['variantni'], true);
            } else if (isset($_GET['variantni'])) {
                $obdobi = DateUtils::urlStringToDate($_GET['variantni'], true);
            }
        } catch (Exception $e) {
            MessageManager::addErrorMessage($e ->getMessage());
        }

        $this ->comboVariantni = new ComboBoxObdobi('variantni');
        $this ->comboVariantni ->className = 'form-control adsfilterforminput_full';
        $this ->comboVariantni ->htmlParams = ['id' => 'adsfilterform_variabilni'];
        if ($this ->autoSubmit) {
            $this->comboVariantni->htmlParams['data-ron-autosubmit'] = '1';
        }
        $this ->comboVariantni ->loadObdobi($this ->database, '', true, false, false, $obdobi); // $variantni=true, $pouzeNeuzavrene=false, $emptyRow=false
        $this ->comboVariantni ->nastavSessionVariantni();

        $this ->vybraneObdobiOd = $this ->comboVariantni ->pocatekObdobi;
        $this ->vybraneObdobiDo = $this ->comboVariantni ->konecObdobi;

        if (!$this ->omezitObdobiOd) {
            $this->omezitObdobiOd = $this->vybraneObdobiOd;
            $this->omezitObdobiDo = $this->vybraneObdobiDo;
        }
    }

     */

    public function render()
    {
        $this ->comboVariantni ->render();

        // prida tlacitka pro posun na dalsi a predchozi obdobi
        echo
            '<span id="adsfilterform_variabilni_fast" class="desktop-only">' .
            '<i class="inline-glyph glyph-button fa glyph-left comboBoxMove" data-submit="1" data-selector="#adsfilterform_variabilni"></i>' .
            '<i class="inline-glyph glyph-button fa glyph-right comboBoxMove" data-step="-1" data-submit="1" data-selector="#adsfilterform_variabilni"></i>' .
            '</span>';
    }
}
