<?php
/**
 * stanislav.elbl, 21.02.2021
 */

namespace RonPortal\Controls;

use Ron\Controls\Browser;
use Ron\DB\Database;
use Ron\TextManager;
use RonPortal\Prava;
use RonPortal\RonPortalSettings;

/**
 * Trida odvozena od Browser, navic pridava tuto funkcnost:
 * - nad seznamem umoznuje zobrazit filtrovaci formular (@see RonPortalFilterForm)
 * - nacita konfiguraci z XML formulare config_<browserCode>. Konfigurace umoznuje
 *   - pridavat, skryvat sloupce a menit jejich vlastnosti
 *   - menit poradi sloupcu
 *   - doplnit texty pro preklady (@see TextManager)
 *   - zobrazit XML formular nad nebo pod seznamem
 */
class RonPortalBrowser extends Browser
{
    public $action;

    /** @var RonPortalFilterForm  */
    public $filterForm;
    public $filterFormUseGet = false;
    public $filterFormAppCode; // kod aplikace pro vyber obdobi
    public $filterFormRights;  // typ prav pro vyber osob
    public $filterFormVcetneExternich = false;

//    /** @var  XmlFormsList  Seznam XML formularu, ktere se zobrazit nad/pod seznamem*/
//    public $xmlFormsList;

    /**
     * @param Database $database
     * @param string $action
     */
    function __construct($database, $action)
    {
        parent::__construct($database);

        $this ->action = $action;
        $this ->browserUrl = "?menuid=$action&";

        $this ->filterFormAppCode = 'ADS';
        $this ->filterFormRights = 'prohlizeni';
        $this ->filterFormVcetneExternich = false;

        $this ->maxPageRows = 200;

//        $this ->xmlFormsList = new XmlFormsList();
    }



    function setFilterForm()
    {
        $this ->filterForm = new RonPortalFilterForm($this ->database, $this ->action, $this ->filterFormUseGet);

        if ($this ->filterFormAppCode) {
            $this->filterForm->nastavObdobi(true, $this->filterFormAppCode, false); // jenotevrene = false
        }

        $prava = is_string($this ->filterFormRights)
            ? Prava::vratPrava($this ->filterFormRights)
            : $this ->filterFormRights;

        if (Prava::pravaNaViceOsob($this ->filterFormRights)) { // napr. pro "pouze vlastni" se vyber nezobrazuje
            $this ->filterForm ->addFilterRozdeleni1(null, $prava);
//            $this ->filterForm ->nastavRozdeleni(true);
//            $this ->filterForm ->f_pravarozdeleni = $prava;
//            $this->filterForm->vcetnePodrizenychRozdeleni = true;

            if ( RonPortalSettings::getIntValue(RonPortalSettings::ROZDELENI2_TYP)) {
                $this ->filterForm ->addFilterRozdeleni2(null, $prava);
//                $this ->filterForm ->nastavRozdeleni2(true);
//                $this->filterForm->vcetnePodrizenychRozdeleni2 = true;
            }
        }

        $this ->filterForm ->nastavOsoby(true, $prava, 0, 0, $this ->filterFormVcetneExternich); // datum od-do podle obdobi
    }


    public function loadConfigurationItem($key, $value, $valueText)
    {
        if ($key === 'filterform') {
            if ($this ->filterForm  &&  $value instanceof \ArrayAccess) {
                foreach ($value as $item) {
                    $this ->filterForm ->loadConfigurationArray($item);
                }
            }
        } else {
            parent::loadConfigurationItem($key, $value, $valueText);
        }
    }

    /**
     * @param \ArrayAccess $colSettings
     */
    public function loadColumnConfiguration($colSettings)
    {
        if (!$colSettings) {
            return;
        }

        //if (!$colSettings['profil']  ||  User::jeVProfilu($colSettings['profil'])) {
        if ($this ->objectConfiguration ->configurationItemEnabled($colSettings)) {
            parent::loadColumnConfiguration($colSettings);
        }
    }


//    public function loadConfigurationItem($key, $value, $valueText)
//    {
//        if ($key === 'xml') {
//            // xml formular, ktery se ma zobrazit
//            $this ->xmlFormsList ->loadSettings($value);
//        } else {
//            parent::loadConfigurationItem($key, $value, $valueText);
//        }
//    }


//    /**
//     * Nacte XML konfiguraci browseru se zadanym kodem
//     * @param Database $database
//     * @param string $browserCode
//     * @return string|null
//     * @deprecated
//     */
//    public static function loadBrowserConfiguration($database, $browserCode)
//    {
//        return RonPortalObjectConfiguration::loadConfigurationFromDatabase($database, $browserCode);
//    }


    /**
     * Nacte konfiguraci browseru z XML sablony
     * @throws \Exception
     */
    function loadConfiguration()
    {
        if (!$this ->code) {
            return;
        }

        $this ->objectConfiguration = new RonPortalObjectConfiguration($this ->database, $this);
        $this ->objectConfiguration ->loadConfiguration($this ->code);
    }


    /**
     * Nacte konfiguraci ze zadaneho xmlTextu
     * @param string $xmlText
     */
    public function loadConfigurationXml($xmlText)
    {
        $this ->objectConfiguration = new RonPortalObjectConfiguration($this ->database, $this);
        $this ->objectConfiguration ->loadConfigurationXml($xmlText);
    }


    function getXmlVariables()
    {
        $variables = [];

        if ($this ->filterForm) {
            if ($this ->filterForm ->showObdobi) {
                $variables['obdobi'] = $this ->filterForm ->vybraneObdobiOd;
                $variables['obdobiDo'] = $this ->filterForm ->vybraneObdobiDo;
            }

            if ($this ->filterForm ->showOsoby) {
                $variables['idPP'] = $this ->filterForm ->vybranaOsoba;
                $variables['RC'] = $this ->filterForm ->vybranaOsobaRC;
                //$variables['osobniCislo'] = $this ->filterForm ->vybranaOsobaOsobniCislo;
                $variables['osobniCislo'] = $this ->filterForm ->vybranaOsobaRC;
                $variables['datumNastupu'] = $this ->filterForm ->vybranaOsobaDatumNastupu;
            }

            // TODO: doplnit rozdeleni atd...
        }

        return $variables;
    }


    function loadFilterData()
    {
        if ($this ->filterForm) {
            $this ->filterForm ->loadData();
        }
    }


    function load($sqlFilter = '')
    {
        $this ->setFilterForm();
        if ($this ->filterForm) {
            $this ->filterForm ->loadConfiguration();
        }

        $this ->loadConfiguration();

        $this ->loadFilterData();

        if ($this ->objectConfiguration instanceof RonPortalObjectConfiguration  &&  $this ->objectConfiguration ->xmlFormsList) {
            $this ->objectConfiguration ->xmlFormsList ->processXMLForms($this ->database, $this ->getXmlVariables());
        }

        parent::load($sqlFilter);
    }


    function renderFilter()
    {
        if ($this ->objectConfiguration instanceof RonPortalObjectConfiguration) {
            $this->objectConfiguration ->renderXmlForms('head');
        }

        if ($this ->filterForm) {
            $this->filterForm->render();
        } else {
            parent::renderFilter();
        }
    }

    public function renderContent()
    {
        if ($this ->objectConfiguration instanceof RonPortalObjectConfiguration) {
            $this->objectConfiguration ->renderXmlForms('top');
        }

        parent::renderContent();

        if ($this ->objectConfiguration instanceof RonPortalObjectConfiguration) {
            $this->objectConfiguration ->renderXmlForms('bottom');
        }
    }


    public function getSQLFilter()
    {
        return $this ->filterForm
            ? $this ->filterForm ->buildSqlFilter()
            : '';
    }


}
