<?php

namespace RonPortal\Controls;

use Ron\Controls\ComboBox;
use Ron\Controls\ComboBoxes;
use Ron\Controls\Option;
use Ron\DateUtils;
use Ron\DB\Database;
use Ron\DB\SqlStatement;
use Ron\GuiUtils;
use Ron\MessageManager;
use Ron\TextManager;
use RonPortal\PravaNaOsoby;
use RonPortal\RonPortalSession;
use RonPortal\RonPortalSettings;
use RonPortal\Rozdeleni;

/**
 * Vychozi filtr na obdobi
 */
class ObdobiFilter extends FilterFormFilter
{
    /** @var RonPortalFilterForm */
    protected $filterForm;

    /** @var ComboBoxObdobi */
    protected $comboObdobi;

    /** @var bool */
    public $jenOtevreneObdobi = false;

    /** @var int    Maximalni pocet zobrazenych zaznamu */
    public $maximalniPocetObdobi = 0;

    /** @var bool       Urcuje, jestli je filtr obdobi zapnuty */
    protected $jenObdobi = false;

    /** @var int|null   Konec zvoleneho obdobi */
    protected $konecObdobi = null;

    public function __construct(RonPortalFilterForm $filterForm, string $name, string $type = self::TYPE_LINKS)
    {
        parent::__construct($name, FilterFormFilter::TYPE_OPTIONS);

        $this ->definesPeriod = true; // filtr omezuje obdobi pro prava a pro dalsi filtry (rozdeleni atd.)

        $this ->filterForm = $filterForm;
        $this ->rowId = 'filterrow_obdobi';

        $this ->caption = TextManager::_('Obdobi');
        $this ->sessionName = 'filtr' . $this ->name; // pro kompatibilitu

        $this ->maximalniPocetObdobi = RonPortalSettings::getIntValue('maximalnipocetobdobi');

        $this ->htmlAttributes = [
            'id' => 'adsfilterform_obdobi',
            'data-ron-autosubmit' => $this ->filterForm ->autoSubmit ? '1' : '0'
        ];
    }

    public function loadConfigurationItem($key, $value, $valueText)
    {
        switch ($key) {
            case 'jenOtevreneObdobi' :
            case 'maximalniPocetObdobi' :
                $this ->{$key} = (int)$value;
                break;

            default :
                parent::loadConfigurationItem($key, $value, $valueText);
        }
    }


    public function load(Database $database)
    {
        if ($this ->filterForm ->obdobiPovinne) {
            $this ->jenObdobi = true;
        } else if (isset($_POST['adsfilterform'])) {
            if ($this ->filterForm ->obdobiNeboDatumPovinne) {
                $this ->jenObdobi = (int)($_POST['jen' . $this ->name] ?? 1) != 2;
                $_SESSION['filtrobdobinebodatum'] = $this ->jenObdobi ? 1 : 2;
            } else {
                $this->jenObdobi = isset($_POST['jen' . $this ->name]);
                $_SESSION['filtrjen' . $this ->name] = $this->jenObdobi;
            }

        } else if (isset($_GET[$this ->name])) {
            if ($this ->filterForm ->obdobiNeboDatumPovinne) {
                $this ->jenObdobi = (int)($_GET['jenobdobi'] ?? 1) != 2;
                $_SESSION['filtrobdobinebodatum'] = $this ->jenObdobi ? 1 : 2;
            } else {
                $this->jenObdobi = (int)($_GET['jenobdobi'] ?? 0);
                $_SESSION['filtrjen' . $this ->name] = $this->jenObdobi;
            }
        } else {
            $this ->jenObdobi = $this ->filterForm ->obdobiNeboDatumPovinne
                ? ($_SESSION['filtrobdobinebodatum'] ?? 1) != 2
                : $_SESSION['filtrjen' . $this ->name] ?? false;
        }

        $obdobi = RonPortalSession::obdobi();

        try {
            if (isset($_POST[$this ->name])) {
                $obdobi = DateUtils::urlStringToDate($_POST[$this ->name], true);  //(int)$_POST['obdobi'];
            }
            else if (isset($_GET[$this ->name])) {
                $obdobi = DateUtils::urlStringToDate($_GET[$this ->name], true); // (int)$_GET['obdobi'];
            }
        } catch (\Exception $e) {
            MessageManager::addErrorMessage($e ->getMessage());
        }

        $this ->comboObdobi = new ComboBoxObdobi($this ->name);
        $this ->comboObdobi
            ->setClassName('form-select adsfilterforminput_full ' . $this ->addClass)
            ->setHtmlParams($this ->htmlAttributes)
            ->setOrderBy($this ->optionsSqlOrder ?? ' PocatekObdobi DESC')
            ->setSqlFilter($this ->optionsSqlFilter);

        $this ->comboObdobi ->maximalniPocetObdobi = $this ->maximalniPocetObdobi;

        $this ->comboObdobi ->loadObdobi($database,
            $this->filterForm ->obdobiAplikace, false,
            $this->jenOtevreneObdobi, false,
            $obdobi);

        $this ->value = $this ->comboObdobi ->pocatekObdobi;
        $this ->konecObdobi = $this ->comboObdobi ->konecObdobi;
    }


    public function getValue(?string $specification = null)
    {
        switch ($specification) {
            case 'datumOd' :
                return $this ->value;

            case 'konecObdobi' :
            case 'datumDo' :
                return $this ->konecObdobi;

            case 'uzavreno' :
                return $this ->comboObdobi
                    ? $this ->comboObdobi ->uzavreno
                    : null;

            case 'popis' :
                return $this ->comboObdobi
                    ? $this ->comboObdobi ->popisObdobi
                    : null;

            case 'jenObdobi' :
                return $this ->jenObdobi;
        }

        return parent::getValue($specification);
    }


    public function renderCaption()
    {
        if ($this->filterForm ->obdobiPovinne) {
            echo $this ->caption;
        } else {
            GuiUtils::renderCheckbox('jenobdobi',
                $this ->caption, $this ->jenObdobi,
                [
                    'data-excluded-checkboxes' => 'input[name=jendatumoddo]',
                    'type' => $this ->filterForm ->obdobiNeboDatumPovinne ? 'radio' : 'checkbox'
                ],
                'clickAutoSubmit', 1, true);
        }
    }


    public function render()
    {
        $this ->comboObdobi ->render();

        // tlacitka pro posun na dalsi a predchozi obdobi
        echo
            '<span id="adsfilterform_obdobi_fast" class="desktop-only">' .
            '<i class="inline-glyph glyph-button fa glyph-left comboBoxMove" data-submit="1" data-selector="#adsfilterform_obdobi"></i>' .
            '<i class="inline-glyph glyph-button fa glyph-right comboBoxMove" data-step="-1" data-submit="1" data-selector="#adsfilterform_obdobi"></i>' .
            '</span>';

        // zobrazi zamek, pokud je obdobi uzavrene
        if ($this ->comboObdobi->uzavreno) {
            echo '<span class="inline-glyph fa glyph-lock"></span>';
        }
    }
}
