<?php

/**
 * Seznam eNeschopenek
 */

namespace RonPortal\Dochazka;


use Ron\Controls\BrowserField;
use Ron\DB\Database;
use Ron\DB\SqlStatement;
use Ron\TextManager;
use RonPortal\Controls\FilterFormFilter;
use RonPortal\Controls\FilterFormFilterItem;
use RonPortal\Controls\RonPortalBrowser;
use RonPortal\PravaNaOsoby;
use RonPortal\RonPortalUtils;
use RonPortal\RozdeleniUtils;


class ENeschopenkaBrowser extends RonPortalBrowser
{
    /** @var PravaNaOsoby */
    private $prava;
    
    /**
     * ENeschopenkaBrowser constructor.
     * @param Database $database
     * @param PravaNaOsoby $prava
     * @throws \Exception
     */
    function __construct($database, $prava)
    {
        parent::__construct($database, 'eneschopenka');

        $jsouMzdy = RonPortalUtils::jeNainstalovanaAplikace($this->database, 'MZDY');

        $this->prava = $prava;

        $this->code = 'browsereneschopenka';

        $this->title = TextManager::_('E_neschopenka');
        $this->cssClass = 'browser';

        $this->sqlFromPart =
            'ENeschopenka JOIN Osoba ON ENeschopenka.RC = Osoba.RC' .
            ' JOIN DruhDavkyNZ ON DruhDavkyNZ.Kod = ENeschopenka.DruhDavky' .
            ($jsouMzdy ? ' LEFT OUTER JOIN DavkyNZ ON DavkyNZ.CisloDokladu = ENeschopenka.CisloDokladu' : '');

        $this ->filterFormAppCode = 'ADS';
        $this ->filterFormRights = 'eneschopenka_prohl';
        $this ->filterFormVcetneExternich = true;

        $this->setFilterForm();
        $this->filterForm->loadData();

        $this ->addField()
            ->setSqlFieldName('Osoba.Prijmeni') ->setHeaderText('Prijmeni')
            ->setOrdering(true) ->setClassName('font-weight-bold')
            ->setCode('col-prijmeni')       // ->setWrap(1)
            ->setVisible($this->filterForm->vsechnyOsoby);

        $this ->addField()
            ->setSqlFieldName('Osoba.Jmeno') ->setHeaderText('Jmeno')
            ->setOrdering(true) ->setClassName('font-weight-bold')
            ->setCode('col-prijmeni')       // ->setWrap(1)
            ->setVisible($this->filterForm->vsechnyOsoby);

        $this->addField()
            ->setSqlFieldName('DruhDavkyNZ.Popis') ->setHeaderText('E_neschopenka_druh')
            ->setOrdering(true) ->setAlign('center')
            ->setCode('col-druhdavky');

        $this->addField()
            ->setSqlFieldName('ENeschopenka.DatumPocatkuDavky') ->setHeaderText('E_neschopenka_datum_pocatku')
            ->setOrdering(true) ->setAlign('center') ->setFormat('date')
            ->setCode('col-datumpocatkudavky');

        $this ->defaultSort = 'col-datumpocatkudavky';

        $this->addField()
            ->setSqlFieldName('ENeschopenka.DatumUkonceniDavky') ->setHeaderText('E_neschopenka_datum_ukonceni')
            ->setOrdering(true) ->setAlign('center') ->setFormat('date')
            ->setCode('col-datumukoncenidavky');

        $this->addField()
            ->setSqlFieldName('ENeschopenka.UkoncenaDavka') ->setHeaderText('E_neschopenka_ukoncena_davka')
            ->setOrdering(true) ->setAlign('center') ->setFormat('anone')
            ->setCode('col-ukoncenadavka');

        $this->addField()
            ->setSqlFieldName('ENeschopenka.PricinaNemoci') ->setHeaderText('E_neschopenka_pricina_nemoci') ->setOrdering(true) ->setAlign('center')
            ->setTranslationPrefix('E_neschopenka_pricina_')
            ->setCode('col-pricinanemoci');

        $this->addField()
            ->setSqlFieldName('ENeschopenka.CisloDokladu')->setHeaderText('E_neschopenka_cislo_dokladu')
            ->setOrdering(true)->setAlign('right')->setVisible($jsouMzdy)
            ->setCode('col-cislodokladu');

        //pokud je nainstalovana aplikace MZDY, zobrazi se i o sloupce
        if ($jsouMzdy) {
            $this->addField()
                ->setSqlFieldName('DavkyNZ.DatumVychazkyOd') ->setHeaderText('E_neschopenka_vychazky_od')
                ->setOrdering(true) ->setAlign('center') ->setFormat('date')
                ->setCode('col-vychazkyod');

            $this->addField()
                ->setSqlFieldName('DavkyNZ.DatumVychazkyDo') ->setHeaderText('E_neschopenka_vychazky_do')
                ->setOrdering(true) ->setAlign('center') ->setFormat('date')
                ->setCode('col-vychazkydo');

            $this->addField(BrowserField::FIELD_TYPE_COMMENT)
                ->setSqlFieldName('{fn_CASTWIDEMEMO(DavkyNZ.IntervalVychazek)}') //->setHeader(TextManager::_('E_neschopenka_vychazky_interval') . ': ')
                ->setHeaderColSpan(-1)->setClassName('poznamka browserpoznamka')
                ->setCode('col-vychazkyinterval');

            $this->addField(BrowserField::FIELD_TYPE_COMMENT)
                ->setSqlFieldName('{fn_CASTWIDEMEMO(DavkyNZ.AdresaPobytu)}') ->setHeader('<strong>' . TextManager::_('E_neschopenka_adresa_pobytu') . '</strong>: ')
                ->setHeaderColSpan(-1)->setClassName('poznamka browserpoznamka')
                ->setCode('col-adresapobytu');
        }

        $this->addField(BrowserField::FIELD_TYPE_COMMENT)
            ->setSqlFieldName('{fn_CASTWIDEMEMO(ENeschopenka.Poznamka)}') ->setHeader('<strong>' . TextManager::_('Poznamka') . '</strong>: ')
            ->setHeaderColSpan(-1)->setClassName('poznamka browserpoznamka')
            ->setCode('col-poznamka');
    }


    function setFilterForm()
    {
        parent::setFilterForm();
//        $this->filterForm = new RonPortalFilterForm($this ->database, 'eneschopenka', true);
//
//        $this->filterForm->nastavObdobi(true, $this->filterFormAppCode, false); // jenotevrene = false
//
//        $prava = Prava::vratPrava($this ->filterFormRights);
//
//        if ($prava ->zobrazitVyberRozdeleni()) { // napr. pro "pouze vlastni" se vyber nezobrazuje
//            $this ->filterForm ->nastavRozdeleni(true);
//            $this ->filterForm ->f_pravarozdeleni = $prava;
//            $this->filterForm->vcetnePodrizenychRozdeleni = true;
//
//            if ( RonPortalSettings::getIntValue(RonPortalSettings::ROZDELENI2_TYP)) {
//                $this ->filterForm ->nastavRozdeleni2(true);
//                $this->filterForm->vcetnePodrizenychRozdeleni2 = true;
//            }
//        }
//
//        $this->filterForm ->nastavOsoby(true, $prava, 0, 0, $this ->filterFormVcetneExternich); // datum od-do podle obdobi

        $this ->filterForm ->nastavAkciGet('eneschopenka');
        $this->filterForm->povolitVsechyOsoby = true;

        $this ->filterForm ->addFilter((new FilterFormFilter('ukoncene'))
            ->addItem(0, TextManager::_('Vse'))
            ->addItem((new FilterFormFilterItem(1, TextManager::_('E_neschopenka_ukoncene')))
                ->setSqlFilter('ENeschopenka.UkoncenaDavka = 1')
            )
            ->addItem((new FilterFormFilterItem(2, TextManager::_('E_neschopenka_neukoncene')))
                ->setSqlFilter('ENeschopenka.UkoncenaDavka = 0')
            )
            ->setDefaultValue(0)
        );
    }

    function getSQLFilter()
    {
        $params = $this->database->createParameters();
        $sql = $this ->filterForm ->buildSqlFilter($params);

        $sql .=
            ($sql ? ' AND ' : '') .
            'ENeschopenka.DatumPocatkuDavky <= ' . $params->addDateParameter($this->filterForm->vybraneObdobiDo) .
            ' AND (ENeschopenka.DatumUkonceniDavky >= ' . $params->addDateParameter($this->filterForm->vybraneObdobiOd) .
            ' OR ENeschopenka.DatumUkonceniDavky IS NULL OR ENeschopenka.UkoncenaDavka = 0)';

        if ($this->filterForm->vsechnyOsoby) {
            $sql .=
                ' AND EXISTS(SELECT ID FROM PracovniPomer' .
                '  WHERE PracovniPomer.RC = Osoba.RC AND PracovniPomer.DatumNastupu <= ' . $params->addDateParameter($this->filterForm->vybraneObdobiDo) .
                '    AND (PracovniPomer.DatumUkonceni >= ' . $params->addDateParameter($this->filterForm->vybraneObdobiOd) . ' OR PracovniPomer.DatumUkonceni IS NULL' .
                ' )' .
                ' AND ' . $this->prava->sqlFiltr('PracovniPomer', $this->filterForm->vybraneObdobiOd, $this->filterForm->vybraneObdobiDo, $params);

            foreach ($this ->filterForm ->getRozdeleniFilters() as $rozdeleniFilter) {
                $value = $rozdeleniFilter ->getValue();
                if (isset($value)) {
                    $filtrR = RozdeleniUtils::sqlFilterRozdeleniPP($this->database,
                        'PracovniPomer',
                        $rozdeleniFilter ->getTypRozdeleni(), $rozdeleniFilter ->getValue(),
                        $this->filterForm->vybraneObdobiOd, $this->filterForm->vybraneObdobiDo,
                        $rozdeleniFilter ->getValue('vcetnePodrizenych'),
                        $params);

                    if ($filtrR) {
                        $sql .=
                            ($sql ? ' AND ' : '') .
                            '(' . $filtrR . ')';
                    }
                }
            }

            $sql .=
                ')';
        } else {
            $sql .= ' AND ENeschopenka.RC = ' . $params->addParameter($this->filterForm->vybranaOsobaRC);
        }

//        switch ($this->filterForm->ukoncene) {
//            case 0 :
//            default :
//                break;
//            case 1 :
//                $sql .= ' AND ENeschopenka.UkoncenaDavka = 1';
//                break;
//            case 2 :
//                $sql .= ' AND ENeschopenka.UkoncenaDavka = 0';
//                break;
//        }

        return new SqlStatement($sql, $params);
    }
}
