<?php
/**
 * stanislav.elbl, 24.02.2021
 */

namespace RonPortal\Dochazka;

use Ron\DateUtils;
use Ron\DB\SqlStatement;
use Ron\StringUtils;

class MesicniVysledkyRBrowser extends VysledkyBrowser
{
    function __construct($database)
    {
        parent::__construct($database, 'mesicnivysledkyr');

        $this->title = \Ron\ronText('Mesicni_vysledky_podle_rozdeleni');

        $this->sqlFromPart = 'MesicniVysledek_R, TypCasoveSlozkyMzdy, Rozdeleni';
        $this->sqlWherePart =
            'TypCasoveSlozkyMzdy.Kod = MesicniVysledek_R.TypCasoveSlozkyMzdy ' .
            ' AND Rozdeleni.KodTypuRozdeleni = MesicniVysledek_R.KodTypuRozdeleni ' .
            ' AND Rozdeleni.Kod = MesicniVysledek_R.Rozdeleni ';

        $this->cssClass .= ' mesicnivysledkyr';

        global $STR_Rozdeleni; // kompat.

        $this->addField()
            ->setSqlFieldName('MesicniVysledek_R.TypCasoveSlozkyMzdy') ->setHeaderText('Kod_casove_slozky') ->setOrdering(1);

        $this->addField()
            ->setSqlFieldName('TypCasoveSlozkyMzdy.Popis') ->setHeaderText('Casova_slozka') ->setOrdering(1);

        $this->addField()
            ->setSqlFieldName('MesicniVysledek_R.Hodiny') ->setHeaderText('Vysledek_Hodiny')
            ->setFormat('hodiny') ->setAlign('right') ->setOrdering(1) ->setClassName('hodiny');

        $this->addField()
            ->setSqlFieldName('MesicniVysledek_R.Dny') ->setHeaderText('Vysledek_Pracovni_dny')
            ->setFormat('number_2') ->setAlign('right') ->setOrdering(1) ->setClassName('dny');

        $this->addField()
            ->setSqlFieldName('MesicniVysledek_R.KalendarniDny') ->setHeaderText('Vysledek_Kalendarni_dny')
            ->setFormat('number_2') ->setAlign('right') ->setOrdering(1) ->setClassName('kalendarnidny');

        $this->addField()
            ->setSqlFieldName('Rozdeleni.Popis') ->setHeaderText('Rozdeleni') ->setOrdering(1);

        $this->addField()
            ->setSqlFieldName('MesicniVysledek_R.Rozdeleni') ->setOrdering(1);

        $this->defaultSort = 1;
        $this->primaryField = 0;
    }


    function setFilterForm()
    {
        parent::setFilterForm();
        $this->filterForm->osobyFiltr = 'PracovniPomer.ZpracovatDochazku = 1';
        $this ->filterForm ->downloadFotoOsobyUrl = '?menuid=editace&action=foto&idpp=';
        $this ->filterForm ->nastavAkciGet('mesicnivysledkyr');
    }

    function load($sqlFilter = '')
    {
        parent::load($sqlFilter);

        $this ->browserUrl = '?menuid=mesicnivysledkyr&idpp=' . $this ->filterForm ->vybranaOsoba .
            '&obdobi=' . DateUtils::dateToUrlString($this ->filterForm ->vybraneObdobiOd);
    }


    function renderFilter()
    {
        $this->odkazyMesicniVysledky('mesicnivysledkyr');
        parent::renderFilter();
    }


    function getSQLFilter()
    {
        $params = $this ->database ->createParameters();

        return new SqlStatement(
            'MesicniVysledek_R.Mesic = ' . $params ->addParameter($this ->database ->dateToParam($this ->filterForm ->vybraneObdobiOd)) .
            ' AND MesicniVysledek_R.RC = ' . $params->addParameter($this ->filterForm ->vybranaOsobaRC) .
            ' AND MesicniVysledek_R.OsobniCislo = ' . $params->addParameter($this ->filterForm ->vybranaOsobaOsobniCislo) .
            ' AND MesicniVysledek_R.DatumNastupu = ' . $params ->addParameter($this ->database ->dateToParam($this ->filterForm ->vybranaOsobaDatumNastupu)),
            $params);
    }

    function getRowAttributes($values, $className, $rowNumber)
    {
        // prida class mv_<kod_casove_slozky>
        $mvClass = 'mv_' . StringUtils::htmlTextConvert(str_replace(' ', '_', $values[0]));
        $className = ($className ? $className . ' ' : '') . $mvClass;

        return parent::getRowAttributes($values, $className, $rowNumber);
    }

}
