<?php
/**
 * stanislav.elbl, 28.02.2021
 */

namespace RonPortal\Dochazka;

use Ron\DB\SqlStatement;
use RonPortal\Controls\DenniZaznamyBrowser;
use RonPortal\PracovniPomer;
use RonPortal\XML\RonPortalXMLForm;

class SmenyDleKalendareBrowser extends DenniZaznamyBrowser
{
    /**
     * @param \Ron\DB\Database $database
     */
    function __construct($database)
    {
        parent::__construct($database, 'kalendar');

        $this->title = \Ron\ronText('MI_Kalendar');

        $this ->code = 'smenydlekalendare';
        $this ->action = 'kalendar';

        $this->sqlSelectPart =
            'SmenaProDenKalendare.Den, Smena.Kod, Smena.Popis,' . // 0..2
            ' Smena.PocatekSmeny, Smena.KonecSmeny, Smena.DelkaSmeny,' . // 3..5
            ' Smena.PocatekPevneCasti, Smena.KonecPevneCasti, Smena.DelkaPevneCasti'; // 6..8
        $this->sqlFromPart =
            'PrirazeniKalendare, SmenaProDenKalendare, Smena';
        $this->sqlWherePart =
            'SmenaProDenKalendare.Kalendar = PrirazeniKalendare.Kalendar ' .
            ' AND Smena.kod = SmenaProDenKalendare.Smena' .
            ' AND PrirazeniKalendare.PlatnostOd <= SmenaProDenKalendare.Den' .
            ' AND (PrirazeniKalendare.PlatnostDo >= SmenaProDenKalendare.Den' .
            ' OR PrirazeniKalendare.PlatnostDo IS NULL)';

        $this ->cssClass .= ' plan-smen-zamestnance';

        $this->addField()
            ->setSqlFieldName('SmenaProDenKalendare.den', 0)
            ->setCode('col-datum')
            ->setFormat('timestamp') ->setHeaderText('Date') ->setClassName('browser_rowheader');

        $this->addField()
            ->setSqlFieldName('Smena.Kod', 1)
            ->setCode('col-kod')
            ->setClassName('kod-smeny');

        $this->addField()
            ->setSqlFieldName('Smena.Popis', 2)
            ->setCode('col-popis')
            ->setHeaderText('Smena') ->setClassName('nazev-smeny')
            ->setTranslationPrefix('db_smena_popis_', 1);

        $this->addField()
            ->setSqlFieldName('Smena.PocatekSmeny', 3)
            ->setCode('col-pocatek')
            ->setHeaderText('Pocatek') ->setFormat('timeofday') ->setAlign('right') ->setClassName('pocatek-smeny');

        $this->addField()
            ->setSqlFieldName('Smena.KonecSmeny', 4)
            ->setCode('col-konec')
            ->setHeaderText('Konec') ->setFormat('timeofday') ->setAlign('right') ->setClassName('konec-smeny');

        $this->addField()
            ->setSqlFieldName('Smena.PocatekPevneCasti', 6)
            ->setCode('col-pocatek-pevne-casti')
            ->setHeaderText('Pocatek_pevne_casti') ->setFormat('timeofday') ->setAlign('right') ->setClassName('pocatek-pevne-casti');

        $this->addField()
            ->setSqlFieldName('Smena.KonecPevneCasti', 7)
            ->setCode('col-konec-pevne-casti')
            ->setHeaderText('Konec_pevne_casti') ->setFormat('timeofday') ->setAlign('right') ->setClassName('konec-pevne-casti');

        $this->addField()
            ->setSqlFieldName('Smena.DelkaSmeny', 5)
            ->setCode('col-delka')
            ->setHeaderText('Delka') ->setFormat('timeofday') ->setAlign('right') ->setClassName('delka-smeny');

        $this->addField()
            ->setSqlFieldName('Smena.DelkaPevneCasti', 8)
            ->setCode('col-delka-pevne-casti') ->setVisible(false)
            ->setHeaderText('Delka_pevne_casti') ->setFormat('timeofday') ->setAlign('right');

        $this->defaultSort = 0;
        $this->primaryField = 0;
    }


    function setFilterForm()
    {
        parent::setFilterForm();

        $this->filterForm->osobyFiltr = 'PracovniPomer.ZpracovatDochazku = 1';
        $this->filterForm->setUseGet(true, $this->action);
    }


    function getSQLFilter()
    {
        if (!$this ->filterForm ->vybranaOsobaRC) {
            // kvuli ibase
            throw new \Exception('Neni vybrana osoba!');
        }

        $params = $this ->database ->createParameters();
        return new SqlStatement(
            'SmenaProDenKalendare.Den >= ' . $params ->addDateParameter($this ->filterForm ->vybraneObdobiOd) .
            ' AND SmenaProDenKalendare.Den <= ' . $params ->addDateParameter($this ->filterForm ->vybraneObdobiDo) .
            ' AND PrirazeniKalendare.RC = ' . $params->addParameter($this ->filterForm ->vybranaOsobaRC) .
            ' AND PrirazeniKalendare.OsobniCislo = ' . $params->addParameter($this ->filterForm ->vybranaOsobaOsobniCislo) .
            ' AND PrirazeniKalendare.DatumNastupu = ' . $params ->addDateParameter($this ->filterForm ->vybranaOsobaDatumNastupu),
            $params);
    }
}
