<?php
/**
 * stanislav.elbl, 25.11.2015
 */

namespace RonPortal\ELearning;

use Ron\DB\Database;
use Ron\DB\DBException;
use Ron\MVC\BaseViewObject;
use Ron\MVC\JsonController;
use Ron\MVC\JsonOutputObject;
use Ron\MVC\Model;
use Ron\RonException;
use Ron\StringUtils;
use Ron\TextManager;
use RonPortal\Log;
use RonPortal\NeniPravoException;
use RonPortal\Prava;
use RonPortal\RonPortalDBRecord;
use RonPortal\Testy\OtazkaDotazniku;
use RonPortal\Testy\TypOdpovedi;
use RonPortal\Testy\VolbaDotazniku;


class TestyController extends JsonController
{
    /** @var  Database */
    var $database;

    /**
     * TestyController constructor.
     * @param Database $database
     */
    public function __construct(Database $database)
    {
        $this->database = $database;
    }


    /**
     * @param int $druhHodnoceni
     * @param int $temaCislo
     * @param int $idRevize Id revize e kurzu - pro nacteni informaci z TestEKurzu
     * @return string
     * @throws DBException
     */
    function zobrazTest($druhHodnoceni, $temaCislo, $idRevize)
    {
        $test = new Test($this ->database);
        $test ->nactiSablonu($druhHodnoceni, $temaCislo, true);
        $test ->nactiSpravneOdpovedi();

        Model::addData('test', $test);

        if ($idRevize) {
            $testEKurzu = TestEKurzu::nactiTestEKurzu($this ->database, $idRevize, $druhHodnoceni, $temaCislo);
            Model::addData('testEKurzu', $testEKurzu);

            $prilohy = PrilohaKurzu::loadPrilohy($this ->database, $idRevize);
            Model::addData('prilohy', $prilohy);
        }

        $typyOdpovedi = TypOdpovedi::nactiTypyOdpovedi($this ->database, ($test ->druhHodnoceni == 6  ||  $test ->druhHodnoceni == 9  ||  $test ->druhHodnoceni == 10) ? 1 : 0); // nacte mozne testove odpovedi
        Model::addData('typyOdpovedi', $typyOdpovedi);
        Model::addData('editace', true); // rezim editace - priznak pro layout

        Model::addViewObject( new BaseViewObject('ronportal/elearning/view_test.php') );

        return 'ronportal/elearning/view_elearning.php';
    }


    private function getKriteriumRecord($druhHodnoceni, $temaCislo, $kodKriteria)
    {
        $kodKriteriaOriginal = (isset($_POST['kodKriteriaOriginal'])  &&  $_POST['kodKriteriaOriginal'] != '')
            ? StringUtils::fromUTF8($_POST['kodKriteriaOriginal'])
            : $kodKriteria; // pri insert provede kontrolu, jestli zaznam se stejnym kodem neexistuje

        $popis = StringUtils::fromUTF8($_POST['popis']);
        if ($popis == '') {
            throw new RonException( \Ron\ronText('Neni_zadan_text_otazky'), 'popis' );
        }

        $rec = new OtazkaDBRecord($this ->database, $druhHodnoceni, $temaCislo, $kodKriteria, $kodKriteriaOriginal, $this);

        $rec ->fPopis ->setNewValue( $popis );
        $rec ->fUpresnujiciPopis ->setNewValue( StringUtils::fromUTF8($_POST['upresnujiciPopis']) );
        $rec ->fTypRozsahu ->setNewValue( StringUtils::fromUTF8($_POST['typRozsahu']) );
        $rec ->fBodovaVaha ->setNewValue( (int)$_POST['bodovaVaha']);
        $rec ->fPovinnaOdpoved ->setNewValue( (int)$_POST['povinnaOdpoved'] );

        return $rec;
    }


    private function vratZpusobHodnoceni($typRozsahu)
    {
        $params = $this ->database ->createParameters();
        $sql =
            'SELECT ZpusobHodnoceni FROM TypRozsahuHodnoceni ' .
            ' WHERE Kod = ' . $params->addParameter($typRozsahu);
        $cursor = $this ->database ->getSqlResult($sql, $params);
        $row = $cursor ->fetch();
        $cursor ->close();

        if (!$row) {
            throw new \Exception('Chyba pri zapisu spravne odpovedi - nenalezen zaznam v tabulce TypRozsahuHodnoceni!');
        }

        return $row[0];
    }

    /**
     * @param OtazkaDBRecord $rec
     * @param int $zpusobHodnoceni
     * @throws \Exception
     * @throws \Ron\DB\DBException
     */
    private function doplnSpravnouOdpoved($rec, $zpusobHodnoceni)
    {
        switch ($zpusobHodnoceni) {
            case 2 : // text
                $rec ->addField('SpravnaSlovniOdpoved', 'string', false, 160, StringUtils::fromUTF8($_POST['spravnaHodnota']));
                break;

            case 0 : // TypOdpovedi::ZPUSOB_ODPOVEDI_VYBER1_DEF : // vyber z preddefinovanych odpovedi
            case 5 : // TypOdpovedi::ZPUSOB_ODPOVEDI_VYBER1 :     // vyber z vlastnich odpovedi
            case 4 : // Hodnotou
                if ( isset($_POST['spravnaHodnota'])  &&  $_POST['spravnaHodnota'] != '') {
                    $rec->fSpravnaHodnota ->setNewValue((int)$_POST['spravnaHodnota']);
                }
                break;

            case 1 :
            case 6 :
                // vicenasobna odpoved - az po zapisu zaznamu
                //throw new \Exception('zapis vicenasobneho vyberu neni im  plementovan!');
                break;

            case 7 : // memo
                break;
        }
    }


    /**
     * Zapise seznam spravnych odpovedi
     * @param int $druhHodnoceni
     * @param int $temaCislo
     * @param string $kodKriteria
     * @throws DBException
     */
    function zapisSpravneOdpovedi($druhHodnoceni, $temaCislo, $kodKriteria)
    {
        $vybrane = [];

        // sestavi si seznam vybranych voleb
        for ($i = 0;  $i < (int)$_POST['pocetVybranych'];  $i++) {
            $vybrane[ (int)$_POST["vybranaVolba$i"] ] = true;
        }

        $params = $this ->database ->createParameters();
        $sql =
            'SELECT Hodnota FROM VycetSpravnychOdpovedi' .
            ' WHERE DruhHodnoceni = ' . $params ->addParameter($druhHodnoceni) .
            ' AND TemaCislo = ' . $params ->addParameter($temaCislo) .
            ' AND KodKriteria = ' . $params ->addParameter($kodKriteria);
        $cursor = $this ->database ->getSqlResult($sql, $params);

        $logText = '';
        $logTextOriginal = '';
        $jeZmena = false;

        while ($row = $cursor ->fetch()) {
            $hodnota = (int)$row[0];

            if ($vybrane[$hodnota]) {
                // ok, je vybrana i v databazi => oznacit, ze se nema vkladat
                $vybrane[$hodnota] = false;

                $logText .= ($logText ? ', ' : '') . $hodnota;
                $logTextOriginal .= ($logTextOriginal ? ', ' : '') . $hodnota;
            } else {
                $params = $this ->database ->createParameters();

                // neni vybrana => musi se smazat
                $sql =
                    'DELETE FROM VycetSpravnychOdpovedi' .
                    ' WHERE DruhHodnoceni = ' . $params ->addParameter($druhHodnoceni) .
                    '   AND TemaCislo = ' . $params ->addParameter($temaCislo) .
                    '   AND KodKriteria = ' . $params ->addParameter($kodKriteria) .
                    '   AND Hodnota = ' . $params ->addParameter($hodnota);

                try {
                    $this->database->sql($sql, $params);
                } catch (DBException $e) {
                    Log::addRecordToDBLog($this ->database, 'VycetSpravnychOdpovedi', 'ERROR', $this,
                        "Pri zapisu spravnych odpovedi doslo k chybe\n" . $e ->dbMessage . "\n\n" . $sql );

                    throw $e;
                    //throw new DBException($this ->database, $sql, 'Pri mazani spravnych odpovedi doslo k chybe!', null, $errorText);
                }

                $jeZmena = true;
                $logTextOriginal .= ($logTextOriginal ? ', ' : '') . $hodnota;
            }
        }
        $cursor ->close();

        foreach ($vybrane as $hodnota => $jeVybrana) {
            if ($jeVybrana) {
                $rec = new RonPortalDBRecord($this ->database, 'VycetSpravnychOdpovedi', $this);
                $rec ->addIntField('DruhHodnoceni', true, $druhHodnoceni);
                $rec ->addIntField('TemaCislo', true, $temaCislo);
                $rec ->addStringField('KodKriteria', true, 10, $kodKriteria);
                $rec ->addIntField('Hodnota', true, $hodnota);
                $rec ->insertRecord();

//                $params = $this ->database ->createParameters();
//
//                $sql =
//                    'INSERT INTO VycetSpravnychOdpovedi (DruhHodnoceni, TemaCislo, KodKriteria, Hodnota)' .
//                    ' VALUES(' .
//                        $params ->addParameter($druhHodnoceni) . ', ' .
//                        $params ->addParameter($temaCislo) . ', ' .
//                        $params ->addParameter($kodKriteria) . ', ' .
//                        $params ->addParameter($hodnota) .
//                    ')';
//
//                if (!$this ->database ->sql($sql, $params)) {
//                    $errorText = $this ->database ->lastErrorText();
//
//                    Log::addRecordToDBLog($this ->database, 'VycetSpravnychOdpovedi', 'ERROR', $this,
//                        "Pri zapisu spravnych odpovedi doslo k chybe\n" . $errorText . "\n\n" . $sql );
//
//                    throw new DBException($this ->database, $sql, 'Pri mazani spravnych odpovedi doslo k chybe!', null, $errorText);
//                }

                $logText .= ($logText ? ', ' : '') . $hodnota;

                $jeZmena = true;
            }
        }

        if ($jeZmena) {
            Log::addRecordToDBLog($this ->database, 'VycetSpravnychOdpovedi', 'UPDATE', $this,
                "DruhHodnoceni: $druhHodnoceni\nTemaCislo: $temaCislo\nKodKriteria: $kodKriteria\n" .
                "Puvodni odpovedi: $logTextOriginal\nNove odpovedi: $logText");
        }
    }


    /**
     * Zapise seznam odpovedi (texty, hodnoty, ...)
     * @param int $druhHodnoceni
     * @param int $temaCislo
     * @param string $kodKriteria
     * @throws \Exception
     */
    function zapisOdpovedi($druhHodnoceni, $temaCislo, $kodKriteria)
    {
        /** @var VolbaDotazniku[] $odpovedi */
        $odpovedi = [];

        // sestavi si seznam odpovedi voleb
        for ($i = 0;  $i < (int)$_POST['pocetOdpovedi'];  $i++) {
            if (!isset($_POST['volbaSmazana' . $i])  ||  !$_POST['volbaSmazana' . $i]) {
                $odpoved = new VolbaDotazniku();
                $odpoved->hodnota = (int)$_POST['hodnotaOdpovedi' . $i];
                $odpoved->popis = StringUtils::fromUTF8($_POST['popisOdpovedi' . $i]);
                $odpoved->koeficient = StringUtils::stringToFloat($_POST['koeficientOdpovedi' . $i]);

                if (isset($odpovedi[$odpoved->hodnota])) {
                    throw new \Exception(\Ron\ronText('Chyba_stejne_hodnoty_odpovedi'));
                }

                $odpovedi[$odpoved->hodnota] = $odpoved;
            }
        }

        $rec = new VycetOdpovediDBRecord($this ->database, $druhHodnoceni, $temaCislo, $kodKriteria, $this);

        $rec ->checkMultiple = false; // nacita vsechny odpovedi najednou
        $rec ->loadRecords();

        while ($rec ->next()) {
            $odpoved = $odpovedi[$rec ->fHodnota ->originalValue];

            if ($odpoved) {
                $rec ->fPopis ->setNewValue($odpoved ->popis);
                $rec ->fKoeficient ->setNewValue($odpoved ->koeficient);
                $updateParams = $this ->database ->createParameters();
                $rec ->updateRecord('Hodnota = ' . $updateParams ->addParameter((int)$odpoved ->hodnota), $updateParams);

                $odpovedi[$rec ->fHodnota ->originalValue] = null;
            } else {
                // tato odpoved ma byt smazana
                $deleteParams = $this ->database ->createParameters();
                $rec ->deleteRecord('Hodnota = ' . $deleteParams ->addParameter((int)$rec ->fHodnota ->originalValue), $deleteParams);
            }
        }

        foreach ($odpovedi as $odpoved) {
            if ($odpoved) { // updatnute otazky jsou null
                // odpoved s novou hodnotou = nova odpoved => insert
                $rec = new VycetOdpovediDBRecord($this ->database, $druhHodnoceni, $temaCislo, $kodKriteria, $this);

                $rec ->fHodnota ->setNewValue($odpoved ->hodnota);
                $rec ->fPopis ->setNewValue($odpoved ->popis);
                $rec ->fKoeficient ->setNewValue($odpoved ->koeficient);

                $rec ->insertRecord();
            }

        }


    }


    /**
     * @param JsonOutputObject $output
     */
    function novyKodOtazky($output)
    {
        $druhHodnoceni = (int)$_GET['druhhodnoceni'];
        $temaCislo = (int)$_GET['temacislo'];

        $novyKod = TestyUtils::novyKodOtazkyKTestu($this ->database, $druhHodnoceni, $temaCislo);
        $output ->addData('kodKriteria', $novyKod);
    }


    /**
     * @throws \Exception
     */
    function updateOtazka()
    {
        $druhHodnoceni = (int)$_POST['druhHodnoceni'];
        $temaCislo = (int)$_POST['temaCislo'];

        $kodKriteria = StringUtils::fromUTF8($_POST['kodKriteria']);
        if ($kodKriteria == '') {
            throw new RonException(\Ron\ronText('Neni_zadan_kod_otazky'), 'kodKriteria');
        }

        $typRozsahu = StringUtils::fromUTF8($_POST['typRozsahu']);
        if ($typRozsahu == '') {
            throw new RonException(\Ron\ronText('Neni_zadan_zpusob_odpovedi'), 'typRozsahu');
        }

        $zpusobHodnoceni = $this->vratZpusobHodnoceni($typRozsahu);

        $rec = $this->getKriteriumRecord($druhHodnoceni, $temaCislo, $kodKriteria);
        $this->doplnSpravnouOdpoved($rec, $zpusobHodnoceni);

        if (isset($_POST['kodKriteriaOriginal']) && $_POST['kodKriteriaOriginal'] != '') {
            // existujici otazka => update
            if (!$rec->loadRecord()) {
                throw new \Exception('Chyba pri editaci otazky - zaznam nebyl nalezen!');
            }

            $rec->updateRecord();
        } else {
            // neexistujici otazka => insert
            $rec ->fPoradi ->setNewValue( OtazkaDBRecord::novePoradi($this ->database, $druhHodnoceni, $temaCislo) );
            $rec->insertRecord();
        }

        if ($zpusobHodnoceni == 5 || $zpusobHodnoceni == 6) {
            $this->zapisOdpovedi($druhHodnoceni, $temaCislo, $kodKriteria);
        }

        if ($zpusobHodnoceni == 1 || $zpusobHodnoceni == 6) {
            $this->zapisSpravneOdpovedi($druhHodnoceni, $temaCislo, $kodKriteria);
        }
    }


    /**
     * @param JsonOutputObject $output
     * @param OtazkaDotazniku[] $otazky
     */
    function jsonOtazky($output, $otazky)
    {
        $otazkyJson = [];
        foreach ($otazky as $otazka) {
            $otazkyJson[] = $otazka ->getJson();
        }

        $output ->addData('otazky', $otazkyJson);
    }


    /**
     * Test importu - nacte otazky jako pro import a vraci je v json - zobrazuji se v nahledu pod importem
     * @param JsonOutputObject $output
     */
    function testImport($output)
    {
        $text = StringUtils::fromUTF8($_POST['text']);
        $otazky = ImportTestuUtils::nactiImportovaneOtazky($text);

        $this ->jsonOtazky($output, $otazky);
    }


    /**
     * @param JsonOutputObject $output
     */
    function importOtazek($output)
    {
        $text = StringUtils::fromUTF8($_POST['text']);
        $otazky = ImportTestuUtils::nactiImportovaneOtazky($text);
        $druhHodnoceni = (int)$_POST['druhHodnoceni'];
        $temaCislo = (int)$_POST['temaCislo'];

        ImportTestuUtils::importujOtazky($this ->database, $otazky, $druhHodnoceni, $temaCislo, $this);

        $this ->jsonOtazky($output, $otazky);
    }


    function updateTest()
    {
        $druhHodnoceni = (int)$_POST['druhHodnoceni'];
        $temaCislo = (int)$_POST['temaCislo'];

        $rec = new TestDBRecord($this->database, $druhHodnoceni, $temaCislo, $this);
        $params = $this ->database ->createParameters();
        $rec ->setWhere(
            'DruhHodnoceni = ' . $params ->addParameter($druhHodnoceni) .
            ' AND TemaCislo = ' . $params ->addParameter($temaCislo),
            $params);

        if (!$rec ->loadRecord()) {
            throw new \Exception('Chyba! Pozadovany test nebyl nalezen!');
        }

        $rec ->fKod ->setNewValue( StringUtils::fromUTF8($_POST['kod']) );
        $rec ->fPopisTematu ->setNewValue( StringUtils::fromUTF8($_POST['popis']) );
        $rec ->fPoznamka ->setNewValue( StringUtils::fromUTF8($_POST['poznamka']) );
        $rec ->fMinPocetBodu ->setNewValue( $_POST['minPocetBodu'] != '' ? (int)$_POST['minPocetBodu'] : null );
        $rec ->fMaxPocetBodu ->setNewValue( $_POST['maxPocetBodu'] != '' ? (int)$_POST['maxPocetBodu'] : null );
        $rec ->fSirkaSloupce ->setNewValue( $_POST['sirkaSloupce'] != '' ? (int)$_POST['sirkaSloupce'] : null );
        $rec ->fEditovatPoznamku ->setNewValue( (int)$_POST['editovatPoznamku'] );
        $rec ->fZobrazitOdpovediUspesne ->setNewValue( (int)$_POST['zobrazitOdpovediUspesne']);
        $rec ->fZobrazitOdpovediNeuspesne ->setNewValue( (int)$_POST['zobrazitOdpovediNeuspesne']);

        $rec ->updateRecord();

        if ((int)$_POST['idRevize']) {
            $rec2 = new RonPortalDBRecord($this->database, 'TestEKurzu', $this);
            $rec2->addField('IDRevize', 'int', true);
            $rec2->addField('DruhHodnoceni', 'int', true);
            $rec2->addField('TemaCislo', 'int', true);
            $rec2->addField('PocetPokusu', 'int', false, 0, $_POST['pocetPokusu'] == '' ? null : (int)$_POST['pocetPokusu']);
            $rec2->addField('CasovyLimit', 'int', false, 0, $_POST['casovyLimit'] == '' ? null : (int)$_POST['casovyLimit']);

            $updateParams = $this ->database ->createParameters();
            $rec2->setWhere(
                'DruhHodnoceni = ' . $updateParams ->addParameter($druhHodnoceni) .
                ' AND TemaCislo = ' . $updateParams ->addParameter($temaCislo) .
                ' AND IdRevize = ' . $updateParams ->addParameter((int)$_POST['idRevize']),
                $updateParams);

            $rec2->updateOrInsert();
        }
    }


    /**
     * @throws \Exception
     */
    public function deleteQuestion()
    {
        // TODO: Zkontrolovat, jestli neexistuje vyplnena odpoved
        ini_set('display_errors', 0);

        $druhHodnoceni = (int)$_POST['druhHodnoceni'];
        $temaCislo = (int)$_POST['temaCislo'];

        $kodKriteria = StringUtils::fromUTF8($_POST['kodKriteria']);
        if ($kodKriteria == '') {
            throw new RonException(\Ron\ronText('Neni_zadan_kod_otazky'), 'kodKriteria');
        }

        $rec = new OtazkaDBRecord($this ->database, $druhHodnoceni, $temaCislo, $kodKriteria, $kodKriteria, $this);

        if (!$rec->loadRecord()) {
            throw new \Exception('Chyba pri odstranovani otazky - zaznam nebyl nalezen!');
        }

        $rec->deleteRecord();
    }


    function handleJsonAction($action, $output)
    {
        switch ($_GET['action']) {
            case 'updateotazka' :
                $this->updateOtazka();
                break;

            case 'deletequestion' :
                $this ->deleteQuestion();
                break;

            case 'updatetest' :
                $this ->updateTest();
                break;

            case 'novykodotazky' :
                $this ->novyKodOtazky($output);
                break;

            case 'testimport' :
                $this ->testImport($output);
                break;

            case 'importotazek' :
                $this ->importOtazek($output);
                break;

            default :
                throw new \Exception('Chyba v TestyController::handleAction - neznama akce!');
        }
    }


    public function handleAction($action)
    {
        TextManager::getInstance() ->loadStrings('elearning.ini');

        if (!Prava::vratHodnotuPrava('editacekurzu')) {
            throw new NeniPravoException();
        }

        switch ($_GET['action']) {
            case 'show' :
                return $this->zobrazTest( (int)$_GET['druhhodnoceni'], (int)$_GET['temacislo'], (int)$_GET['idrevize']);

            default :
                return parent::handleAction($action);
        }
    }
}
