<?php

/**
 * Seznam pohybu na uctu pro vybraneho stravnika
 */

namespace RonPortal\Jidelna;

use Ron\DateUtils;
use Ron\DB\SqlStatement;
use Ron\TextManager;
use RonPortal\Controls\RonPortalBrowser;


class PohybyNaUctuBrowser extends RonPortalBrowser
{
    function __construct($database)
    {
        parent::__construct($database, 'pohybynauctu');

        $this->title = TextManager::_('Pohyby_na_uctu');
        $this ->code = 'browserpohybynauctu';
        $this ->showFooter = true;

        // definice dotazu a hlavicky
        $this->sqlFromPart = 'PohybNaUctu, TypPohybu';
        $this->sqlWherePart =
            'TypPohybu.Kod=PohybNaUctu.TypPohybu';

        $this->addField()
            ->setSqlFieldName('PohybNaUctu.DatumCasPohybu')
            ->setCode('col-datumcas')
            ->setHeaderText('Datum_a_cas') ->setFormat('datetime') ->setOrdering(1);
        $this->defaultSort = 'col-datumcas';
        $this->primaryField = 0;

        $this->addField()
            ->setSqlFieldName('TypPohybu.Popis')
            ->setCode('col-typpohybu')
            ->setHeaderText('Typ_pohybu') ->setOrdering(1)
            ->setFooter(TextManager::_('Celkem'));

        $this->addField()
            ->setSqlFieldName('PohybNaUctu.Castka')
            ->setCode('col-castka')
            ->setHeaderText('Castka') ->setFormat('curr') ->setAlign('right') ->setOrdering(1)
            ->setShowSum(true);

        $this->addField()
            ->setSqlFieldName('PohybNaUctu.PopisPohybu')
            ->setCode('col-popis')
            ->setHeaderText('Popis') ->setOrdering(1);

        $this ->filterFormAppCode = 'JIDELNA';
        $this ->filterFormRights = 'prohl_jidelna';
        $this ->filterFormVcetneExternich = true;
        $this ->filterFormUseGet = true;
    }

    function setFilterForm()
    {
        parent::setFilterForm();
        $this ->filterForm ->addFilter(new StavUctuFilter($this ->filterForm));
    }


    function getSQLFilter()
    {
        $params = $this ->database ->createParameters();
        $result = $this ->filterForm ->buildSqlFilter($params);

        return new SqlStatement(
            $result . ($result ? ' AND ' : '') .
            'PohybNaUctu.DatumCasPohybu >= ' . $params ->addDateParameter($this ->filterForm ->vybraneObdobiOd) .
            ' AND PohybNaUctu.DatumCasPohybu <= ' . $params ->addTimestampParameter(DateUtils::endOfTheDay($this ->filterForm ->vybraneObdobiDo)) .
            ' AND PohybNaUctu.RC = ' . $params->addParameter($this ->filterForm ->vybranaOsobaRC) .
            ' AND PohybNaUctu.OsobniCislo = ' . $params->addParameter($this ->filterForm ->vybranaOsobaOsobniCislo) .
            ' AND PohybNaUctu.DatumNastupu = ' . $params->addDateParameter($this ->filterForm->vybranaOsobaDatumNastupu),
            $params);
    }
}
