<?php

namespace RonPortal\PokladniKniha;

use Exception;
use Ron\Controls\Browser;
use Ron\Controls\BrowserField;
use Ron\Controls\ComboBox;
use Ron\DateUtils;
use Ron\DB\Database;
use Ron\DB\DBException;
use Ron\DB\DBUtils;
use Ron\DB\SQLUtils;
use Ron\GuiUtils;
use Ron\MessageManager;
use Ron\StringUtils;
use Ron\TextManager;
use RonPortal\Controls\ComboBoxesRozdeleni;
use RonPortal\Controls\RonPortalBrowser;
use RonPortal\Controls\RozdeleniBrowserField;
use RonPortal\NeniPravoException;
use RonPortal\PracovniPomer;
use RonPortal\Prava;
use RonPortal\RonPortalSettings;
use RonPortal\RozdeleniOsob;
use RonPortal\Security;
use RonPortal\TypRozdeleni;
use function Ron\ronText;

class RadekPokladniKnihyBrowserField extends BrowserField
{
    /** @var PokladniKniha */
    public $pokladniKniha;

    public function __construct($pokladniKniha)
    {
        parent::__construct();
        $this ->pokladniKniha = $pokladniKniha;
    }

    public function lzeZobrazitRadek($rowData)
    {
        $pravo = Prava::vratPrava('pkniha_vloz', 'pkniha_vloz_' . $rowData[RadekPokladniKnihyBrowser::TYP_POHYBU_INDEX]);
        if (!$pravo ->lzeZobrazitPP($this->pokladniKniha->idPP, $this->pokladniKniha->datumPohybu, $this->pokladniKniha->datumPohybu)) {
            return false;
        }

        return true;
    }

}

class EditaceRadkuPKField extends RadekPokladniKnihyBrowserField
{
    /**
     * @param PokladniKniha $pokladniKniha
     */
    function __construct($pokladniKniha)
    {
        parent::__construct($pokladniKniha);
        $this ->code = 'col-edit';
        $this ->align = 'left';
    }

    /**
     * @param mixed $value
     * @param int $rowNumber
     * @param string $recordId
     * @param array $rowData
     * @return string
     * @throws Exception
     */
    function getViewText($value, $rowNumber, $recordId, $rowData)
    {
        if (!$this->lzeZobrazitRadek($rowData)) {
            return '';
        }

        return
            '<i class="inline-glyph glyph-button fa glyph-edit open-dialog"' .
            ' data-dialog="#radek_poklk_dialog" data-ronform-url="?menuid=pokladnikniha&action=radek&idpokl=' . $this->pokladniKniha->vratID() . '&record="' .
            ' data-ronform-record="' . $rowData[RadekPokladniKnihyBrowser::CISLO_RADKU_INDEX] . '"' . // id radku
            ' title="' . ronText('Editovat_zaznam') . '">';
    }
}

class KopieRadkuPKField extends RadekPokladniKnihyBrowserField
{
    /**
     * @param PokladniKniha $pokladniKniha
     */
    function __construct($pokladniKniha)
    {
        parent::__construct($pokladniKniha);
        $this ->code = 'col-copy';
        $this ->align = 'left';
    }

    /**
     * @param mixed $value
     * @param int $rowNumber
     * @param string $recordId
     * @param array $rowData
     * @return string
     * @throws Exception
     */
    function getViewText($value, $rowNumber, $recordId, $rowData)
    {
        if (!$this->lzeZobrazitRadek($rowData)) {
            return '';
        }

        return
            '<i class="inline-glyph glyph-button fa glyph-copy open-dialog"' .
            ' data-dialog="#radek_poklk_dialog" data-ronform-url="?menuid=pokladnikniha&action=radek&idpokl=' . $this->pokladniKniha->vratID() . '&record=' . $rowData[RadekPokladniKnihyBrowser::CISLO_RADKU_INDEX] . '"' .
            ' title="' . ronText('Kopirovat_zaznam') . '">';
    }
}


class ZruseniRadkuPKField extends RadekPokladniKnihyBrowserField
{
    /**
     * @param PokladniKniha $pokladniKniha
     */
    function __construct($pokladniKniha)
    {
        parent::__construct($pokladniKniha);
        $this ->code = 'col-delete';
        $this ->align = 'left';
    }


    /**
     * @param mixed $value
     * @param int $rowNumber
     * @param string $recordId
     * @param array $rowData
     * @return string
     * @throws Exception
     */
    function getViewText($value, $rowNumber, $recordId, $rowData)
    {
        if (!$this->lzeZobrazitRadek($rowData)) {
            return '';
        }

        return GuiUtils::changeLocationQuest(
            '<i class="inline-glyph glyph-button fa glyph-delete" title="' . TextManager::_('Zrusit_zaznam') . '"></i>',
            TextManager::_('PoklK_Opravdu_zrusit_radek'),
            "?menuid=pokladnikniha&action=zrusitradekpokladniknihy&record=" . $this->pokladniKniha->vratID() . "&radek=" . $rowData[RadekPokladniKnihyBrowser::CISLO_RADKU_INDEX] . Security::csrfUrlParameter(),
            'data-ron-send-position="1"');
    }
}


class DokumentyRadkuPKField extends BrowserField
{
    var $lzeEditovat;

    /**
     * @param Database $database
     * @param bool $lzeEditovat
     */
    function __construct($database, $lzeEditovat)
    {
        parent::__construct($database);
        $this->code = 'col-dokumenty';
        $this->align = 'center';

        $this ->lzeEditovat = $lzeEditovat;
    }


    /**
     * @param mixed $value
     * @param int $rowNumber
     * @param string $recordId
     * @param array $rowData
     * @return string
     * @throws DBException
     */
    function getViewText($value, $rowNumber, $recordId, $rowData)
    {
        $params = $this->database->createParameters();

        $sql =
            'SELECT DokumentPokladniKnihy.Id, Dokument.Popis' .
            '  FROM DokumentPokladniKnihy JOIN Dokument ON Dokument.ID = DokumentPokladniKnihy.ID' .
            ' WHERE IDPokladniKnihy = ' . $params->addParameter($rowData[RadekPokladniKnihyBrowser::ID_POKLADNI_KNIHY_INDEX]) .
            '   AND CisloRadku = ' . $params->addParameter($rowData[RadekPokladniKnihyBrowser::CISLO_RADKU_INDEX]);

        $result = '';

        $cursor = $this->database->getSqlResult($sql, $params);
        while ($row = $cursor->fetch()) {
            $result .=
                '<a target="_blank" href="?menuid=pokladnikniha&action=dokumentdownload&id=' . (int)$rowData[RadekPokladniKnihyBrowser::ID_POKLADNI_KNIHY_INDEX] . '&record=' . $row[0] . Security::csrfUrlParameter() . '">' .
                '<i class="inline-glyph glyph-button fa glyph-attachment" title="' . StringUtils::htmlTextConvert($row[1]) . '"></i>' .
                '</a>';

        }
        $cursor ->close();

        if ($this ->lzeEditovat) {
            $result .=
                '<a href="#" title="' . TextManager::_('Vlozit_novy_dokument') . '">' .
                '<i class="inline-glyph fa glyph-upload show-dokument-dialog" data-fields="CisloRadku" data-field-cisloradku="' . $rowData[RadekPokladniKnihyBrowser::CISLO_RADKU_INDEX] . '"></i>' .
                '</a>';
        }

        return $result;
    }
}

class RadekPokladniKnihyBrowser extends RonPortalBrowser
{
    const CISLO_RADKU_INDEX = 0;
    const TYP_POHYBU_INDEX = 5;
    const ID_POKLADNI_KNIHY_INDEX = 19;

    public $zobrazitNovyRadek;

    public $pokladniKniha;
    public $idPokladniKnihy;
    public $datum;
    public $editovatRadek;
    public $kopirovatRadek;

    public $formaction;

    public $seznamPolozekPokladniKnihy;

    /**
     * @param Database $database
     * @param PokladniKniha $pokladniKniha
     * @param SeznamPolozekPokladniKnihy $seznamPolozek
     * @param string $akce
     * @throws Exception
     */
    public function __construct($database, PokladniKniha $pokladniKniha, SeznamPolozekPokladniKnihy $seznamPolozek, string $akce)
    {
        parent::__construct($database, 'pokladnikniha');

        switch ($akce) {
            case 'editovatradekpokladniknihy' :
                $this->formaction = 'ulozradekpokladniknihy';
                if (isset($_POST['CisloRadku'])) $this->editovatRadek = $_POST['CisloRadku'];
                else $this->editovatRadek = $_GET['radek'] ?? null;
                break;

            case 'kopirovatradekpokladniknihy' :
                $this->formaction = 'vlozradekpokladniknihy';
                $this->kopirovatRadek = $_GET['radek'] ?? null;
                break;


            case 'pridatradek' :
                $this->formaction = 'vlozradekpokladniknihy';
                $this->zobrazitNovyRadek = true;
                break;
        }

        $this->pokladniKniha = $pokladniKniha;
        $this->idPokladniKnihy = $pokladniKniha->vratID();
        $this->seznamPolozekPokladniKnihy = $seznamPolozek;

        $this->code = 'browserradekpokladniknihy' . ($seznamPolozek->cislo != 1 ? "_$seznamPolozek->cislo" : '');
        $this->tableId = 'radekpokladniknihy';

        $this->showMessages = false;

        $this->sqlSelectPart =
            'RadekPokladniKnihy.CisloRadku, RadekPokladniKnihy.DatumPohybu, RadekPokladniKnihy.Castka, RadekPokladniKnihy.CastkaBezDPH, RadekPokladniKnihy.CastkaDPH, ' . //0 - 4
            'RadekPokladniKnihy.TypPolozky, RadekPokladniKnihy.Popis, RadekPokladniKnihy.Poznamka, ZpusobPlatbyPK.Popis, TypPolozkyPokladniKnihy.Popis, ' . //5 - 9
            'RadekPokladniKnihy.KodTypuRozdeleni, RadekPokladniKnihy.Rozdeleni, RadekPokladniKnihy.KodTypuRozdeleni2, RadekPokladniKnihy.Rozdeleni2, ' .  //10 - 13
            'Rozdeleni.Popis, R2.Popis, RadekPokladniKnihy.Rozdeleni3, R3.Popis, RadekPokladniKnihy.ZpusobPlatby, RadekPokladniKnihy.IDPokladniKnihy'; // 14 - 19

        if (PokladniKnihaController::zobrazitRozdeleni4($this->database)) {
            $this->sqlSelectPart .=
                ' , R4.Kod, R4.Popis '; // 20 - 21
        }

        $this->sqlFromPart =
            'RadekPokladniKnihy  ' .
            'JOIN TypPolozkyPokladniKnihy ON (TypPolozkyPokladniKnihy.Kod = RadekPokladniKnihy.TypPolozky) ' .
            'JOIN ZpusobPlatbyPK ON (ZpusobPlatbyPK.Kod = RadekPokladniKnihy.ZpusobPlatby) ' .
            'LEFT OUTER JOIN Rozdeleni ON Rozdeleni.KodTypuRozdeleni = RadekPokladniKnihy.KodTypuRozdeleni AND Rozdeleni.Kod = RadekPokladniKnihy.Rozdeleni ' .
            'LEFT OUTER JOIN Rozdeleni R2 ON R2.KodTypuRozdeleni = RadekPokladniKnihy.KodTypuRozdeleni2 AND R2.Kod = RadekPokladniKnihy.Rozdeleni2 ' .
            'LEFT OUTER JOIN Rozdeleni R3 ON R3.KodTypuRozdeleni = RadekPokladniKnihy.KodTypuRozdeleni3 AND R3.Kod = RadekPokladniKnihy.Rozdeleni3 ';

        if (PokladniKnihaController::zobrazitRozdeleni4($this->database)) {
            $this->sqlFromPart .=
                'LEFT OUTER JOIN Rozdeleni R4 ON R4.KodTypuRozdeleni = RadekPokladniKnihy.KodTypuRozdeleni4 AND R4.Kod = RadekPokladniKnihy.Rozdeleni4 ';
        }

        $this->sqlWherePart =
            'RadekPokladniKnihy.IDPokladniKnihy = ' . $this->idPokladniKnihy;

        $this->primaryField = 0;

        $this->addField()
            ->setHeaderText('datum_pohybu')->setSqlFieldIndex(1)->setSqlFieldName('RadekPokladniKnihy.DatumPohybu')
            ->setFormat('date')->setAlign('right')->setCode('col-datum-pohybu');

        $this->addField()
            ->setHeaderText('typ_polozky')->setSqlFieldIndex(9)->setSqlFieldName('TypPolozkyPokladniKnihy.Popis')
            ->setAlign('left')->setCode('col-typ-polozky')->setTranslationPrefix('db_typpolozkypokladniknihy_popis_', 5);

        $this->addField()
            ->setHeaderText('popis')->setSqlFieldIndex(6)->setSqlFieldName('RadekPokladniKnihy.Popis')
            ->setAlign('left')->setCode('col-popis');

        if (RonPortalSettings::getIntValue('typrozdelenipoklk')) {
            $typRozdeleni = TypRozdeleni::getTypRozdeleni($database, RonPortalSettings::getIntValue('typrozdelenipoklk'));

            $this->addField(new RozdeleniBrowserField($this->database, 11, 14))->setHeaderText($typRozdeleni->popis)->setCode('col-rozdeleni')
                ->setSqlFieldName('RadekPokladniKnihy.Rozdeleni')->setOrdering(false);
        }
        if (RonPortalSettings::getIntValue('typrozdelenipoklk2')) {
            $typRozdeleni = TypRozdeleni::getTypRozdeleni($database, RonPortalSettings::getIntValue('typrozdelenipoklk2'));

            $this->addField(new RozdeleniBrowserField($this->database, 13, 15, 'col-rozdeleni2'))->setHeaderText($typRozdeleni->popis)->setCode('col-rozdeleni2')
                ->setSqlFieldName('RadekPokladniKnihy.Rozdeleni2')->setOrdering(false);
        }
        if (RonPortalSettings::getIntValue('typrozdelenipoklk3')) {
            $typRozdeleni = TypRozdeleni::getTypRozdeleni($database, RonPortalSettings::getIntValue('typrozdelenipoklk3'));

            $this->addField(new RozdeleniBrowserField($this->database, 16, 17, 'col-rozdeleni3'))->setHeaderText($typRozdeleni->popis)->setCode('col-rozdeleni3')
                ->setSqlFieldName('RadekPokladniKnihy.Rozdeleni3')->setOrdering(false);
        }
        if (PokladniKnihaController::zobrazitRozdeleni4($this->database) && RonPortalSettings::getIntValue('typrozdelenipoklk4')) {
            $typRozdeleni = TypRozdeleni::getTypRozdeleni($database, RonPortalSettings::getIntValue('typrozdelenipoklk4'));

            $this->addField(new RozdeleniBrowserField($this->database, 20, 21, 'col-rozdeleni4'))->setHeaderText($typRozdeleni->popis)->setCode('col-rozdeleni4')
                ->setSqlFieldName('RadekPokladniKnihy.Rozdeleni4')->setOrdering(false);
        }

        if ($this->seznamPolozekPokladniKnihy->lzeZobrazitCastkuBezDPH()) {
            $this->addField()
                ->setHeaderText('castkaBezDPH')->setSqlFieldIndex(3)->setSqlFieldName('RadekPokladniKnihy.CastkaBezDPH')
                ->setFormat('number2')->setAlign('right')->setCode('col-castka-bez-dph');
        }
        if ($this->seznamPolozekPokladniKnihy->lzeZobrazitCastkuDPH()) {
        $this->addField()
            ->setHeaderText('castkaDPH')->setSqlFieldIndex(4)->setSqlFieldName('RadekPokladniKnihy.CastkaDPH')
            ->setFormat('number2')->setAlign('right')->setCode('col-castka-dph');
        }
        if ($this->seznamPolozekPokladniKnihy->lzeZobrazitCastku()) {
            $this->addField()
                ->setHeaderText('castka')->setSqlFieldIndex(2)->setSqlFieldName('RadekPokladniKnihy.Castka')
                ->setFormat('number2')->setAlign('right')->setCode('col-castka');
        }

        $this->addField()
            ->setHeaderText('PoklK_zpusobplatby')->setSqlFieldIndex(8)->setSqlFieldName('ZpusobPlatbyPK.Popis')
            ->setAlign('left')->setCode('col-zpusob-platby')->setTranslationPrefix('db_zpusobplatbypk_popis_', 18);

        if ($this->pokladniKniha->lzeEditovat(false) &&
            $akce != 'editovatradekpokladniknihy' &&
            $akce != 'kopirovatuctovanisluzebky' &&
            $akce != 'pridatuctovanisluzebky' &&
            $akce != 'ulozuctovanisluzebky'
        ) {
            $this ->addField(new EditaceRadkuPKField($this->pokladniKniha));
            $this ->addField(new KopieRadkuPKField($this->pokladniKniha));
            $this ->addField(new ZruseniRadkuPKField($this->pokladniKniha));

        }

        $this ->addField(new DokumentyRadkuPKField($database, $this->pokladniKniha->lzeEditovat(false)));
    }

    function setFilterForm()
    {
        $this->filterForm = null;
    }
//
//
//    /**
//     * @param int $index
//     * @param BrowserField $field
//     * @param mixed $value
//     * @param int $rowNumber
//     * @param mixed $recordId
//     * @param array $values
//     * @throws DBException
//     */
//    public function renderFieldEdit($index, $field, $value, $rowNumber, $recordId, $values)
//    {
//        switch ($field ->sqlFieldName) {
//            case 'RadekPokladniKnihy.DatumPohybu' :
//                if (isset($_POST['datumpohybu'])) $value = StringUtils::htmlTextConvert($_POST['datumpohybu']);
//                else if (!$values && $this->datum) $value = date('j.n.Y', $this->datum);
//                else $value = DBUtils::getFormatedValue($this ->database, $field ->format, $value);
//
//                echo
//                    '<td style="white-space:nowrap">' .
//
//                    '<div class="input-group">' .
//                    '<input type="text" name="datumpohybu" class="form-input input-date appinput inputDate ' . MessageManager::getClass('Den') . '" value="' . $value . '" maxlength="10" size="10" />' .
//                    '<i class="input-group-text fa glyph-calendar showcalendar"  data-roncalendar-inputname="datumpohybu"></i>' .
//                    '</div>' .
//
//                    '<input type="hidden" name="PokladniKniha_ID" value="' . $this->idPokladniKnihy . '" />' .
//                    '<input type="hidden" name="CisloRadku" value="' . ($values ? $values[0] : '') . '" />' .
//                    '<input type="hidden" name="EditaceRadkuPK" value="1">' .
//                    "<input type='hidden' name='typy' id='seznamtypu' value='" . json_encode($this->seznamPolozekPokladniKnihy->jsonObject) . "' />" .
//
//                    "</td>\n";
//
//                break;
//
//            case 'RadekPokladniKnihy.Castka' :
//                $value = $_POST['castka'] ?? (float)$value;
//
//                echo '<td><input type="text" name="castka" class="form-input inputFloat" value="' . StringUtils::htmlTextConvert($value) . '" size="8" maxlength="8" />';
//                echo '</td>';
//                break;
//
//
//            case 'RadekPokladniKnihy.CastkaDPH' :
//                $value = $_POST['castkaDPH'] ?? (float)$value;
//
//                echo
//                    '<td>' .
//                    '<input type="text" name="castkaDPH" id="row_castka_dph" class="form-input inputFloat" value="' . StringUtils::htmlTextConvert($value) . '" size="8" maxlength="8" />' .
//                    '</td>';
//                break;
//
//            case 'RadekPokladniKnihy.CastkaBezDPH' :
//                $value = $_POST['castkaBezDPH'] ?? (float)$value;
//
//                echo
//                    '<td>' .
//                    '<input type="text" name="castkaBezDPH" id="row_castka_bez_dph" class="form-input inputFloat" value="' . StringUtils::htmlTextConvert($value) . '" size="8" maxlength="8" />' .
//                    '</td>';
//                break;
//
//            case 'RadekPokladniKnihy.Popis' :
//                if (isset($_POST['popis'])) $value = $_POST['popis'];
//                echo '<td><input type="text" class="form-input" name="popis" value="' . StringUtils::htmlTextConvert($value) . '" size="40" maxlength="160"></td>';
//                break;
//
//            case 'TypPolozkyPokladniKnihy.Popis' :
//                echo '<td id="typ_polozky">';
//                if (isset($_POST['typ'])) {
//                    $value = $_POST['typ'];
//                } else if ($values) {
//                    $value = $values[5];
//                } else {
//                    $value = null;
//                }
//
//                $params = $this->database->createParameters();
//                $combo = new ComboBox('typ');
//                $combo->loadData($this->database, 'SELECT TypPolozkyPokladniKnihy.Kod, TypPolozkyPokladniKnihy.Popis FROM TypPolozkyPokladniKnihy WHERE '.
//                    SQLUtils::getINCondition($this->database, 'TypPolozkyPokladniKnihy.Kod', $this->seznamPolozekPokladniKnihy->seznamTypuSQL, $params), $value, $params);
//                $combo->htmlParams = ['id' => 'typRadkuUctovaniSC', 'class' => 'form-input'];
//                $combo->dataTypeComparison = false;
//                $combo->render();
//
//                echo "</td>\n";
//                break;
//
//            case 'ZpusobPlatbyPK.Popis' :
//                echo '<td>';
//
//                $params = $this->database->createParameters();
//                $value =  (isset($_POST['zpusobplatby'])) ? $_POST['zpusobplatby'] : ($values ? $values[18] : null);
//                $combo = new ComboBox('zpusobplatby');
//                $combo ->dataTypeComparison = false;
//                $combo ->loadData($this ->database, 'SELECT Kod, Popis FROM ZpusobPlatbyPK WHERE RonPortalBrowser = ' . $params->addParameter($this->seznamPolozekPokladniKnihy->cislo) .
//                    ($this->seznamPolozekPokladniKnihy->cislo == 1 ? ' OR RonPortalBrowser IS NULL ' : '') .
//                    ' ORDER BY Popis', $value, $params);
//                $combo ->render();
//
//                echo "</td>\n";
//                break;
//
//            case 'RadekPokladniKnihy.Rozdeleni' :
//            case 'RadekPokladniKnihy.Rozdeleni2' :
//            case 'RadekPokladniKnihy.Rozdeleni3' :
//                if ($field->sqlFieldName == 'RadekPokladniKnihy.Rozdeleni') {
//                    $index = 11;
//                    $poradiRozdeleni = '';
//
//                } elseif ($field->sqlFieldName == 'RadekPokladniKnihy.Rozdeleni2') {
//                    $index = 13;
//                    $poradiRozdeleni = '2';
//                } else {
//                    $index = 16;
//                    $poradiRozdeleni = '3';
//                }
//
//                $varname = "rozdeleni{$poradiRozdeleni}";
//                $typRozdeleni = RonPortalSettings::getIntValue("typrozdelenipoklk{$poradiRozdeleni}");
//                $pouzeVlastni = RonPortalSettings::getIntValue("rozdelenipoklk{$poradiRozdeleni}_pouzevlastni");
//                $rozdeleni = null;
//                if (RonPortalSettings::getIntValue("rozdelenipoklk{$poradiRozdeleni}_vychozihodnota")) {
//                    $r = RozdeleniOsob::nactiRozdeleniOsoby($this ->database,
//                        $this->pokladniKniha->idPP, $typRozdeleni,
//                        time(), time(), (RonPortalSettings::getIntValue("rozdelenipoklk{$poradiRozdeleni}_vychozihodnota") == 2) ? 'Hlavni = 1' : null );
//
//                    if ($r) {
//                        $rozdeleni = $r[0]->kod;
//                    }
//                }
//
//                $comboBoxesRozdeleni = new ComboBoxesRozdeleni($this->database, $varname, $varname);
//                $comboBoxesRozdeleni ->loadRozdeleni($pouzeVlastni, PracovniPomer::nactiPP($this->database, $this->pokladniKniha->idPP), $typRozdeleni,
//                    isset($_POST[$varname]) ? $_POST[$varname] : ($values ? $values[$index] : $rozdeleni), false);
//
//
//                echo '<td>';
//                $comboBoxesRozdeleni->combo1->render();
//
//                echo "</td>\n";
//                break;
//
//            default :
//                echo "<td></td>\n";
//        }
//    }
//
//    public function renderLine($values, $className, $rowNumber, $edit = false)
//    {
//        if ($values && $this->editovatRadek == $values[0]) {
//            $edit = true;
//        }
//
//        if ($edit) $className .= ' editing';
//        parent::renderLine($values, $className, $rowNumber, $edit);
//
//
///*
//        $this ->showRozdeleni($values, $className, $edit);
//*/
//        // kopie aktualniho radku => zobrazi jej jeste jednou s nullovym cislem
//        if ($values && $this ->kopirovatRadek == $values[0]) {
//            $values[0] = null;
//            $this ->renderLine($values, '', 0, true);
//        }
//    }
//
//    public function renderCursor($cursor)
//    {
//        parent::renderCursor($cursor);
//
//        // prida navic jeden novy radek pro editaci
//        if ($this ->zobrazitNovyRadek) {
//            $this ->renderLine(null, '', 0, true); // edit = true
//        }
//    }

    public function render()
    {
        parent::render();

        if ($this->pokladniKniha->lzeEditovat(false)) {
            echo
                "<div class='text_link' id='radekPoklKBrowserLinks'><ul class='linkslist'>\n" .
                "<li><a href='#' class='open-dialog' data-dialog='#radek_poklk_dialog'>" . ronText('Novy_radek') . "</a></li>\n" .
                "</ul></div>\n";
        }
    }

//
//    /**
//     * @param RadekPokladniKnihyRecord $rec
//     * @return bool
//     * @throws Exception
//     */
//    private static function loadPostToRecord(RadekPokladniKnihyRecord $rec)
//    {
//        $prava = Prava::vratPrava('pkniha_vloz', 'pkniha_vloz_' . $_POST['typ']);
//        if (!$prava->jsouNejakePrava())
//            throw new NeniPravoException();
//
//        if ($_POST['datumpohybu'] == '') {
//            throw new Exception(ronText('PoklK_neni_datum_pohybu'));
//        }
//        if ($_POST['castka'] == '') {
//            throw new Exception(ronText('PoklK_neni_castka'));
//        }
//        if ($_POST['typ'] == '') {
//            throw new Exception(ronText('PoklK_neni_typ'));
//        }
//        if ($_POST['popis'] == '') {
//            throw new Exception(ronText('PoklK_neni_popis'));
//        }
//
//        $castka = StringUtils::stringToFloat($_POST['castka']);
//        $castkaBezDPH = StringUtils::stringToFloat($_POST['castkaBezDPH']);
//        $castkaDPH = StringUtils::stringToFloat($_POST['castkaDPH']);
//        $datum = DateUtils::dateStringToTimestamp($_POST['datumpohybu']);
//
//        $rec->castka->setNewValue($castka);
//        $rec->castkaBezDPH->setNewValue($castkaBezDPH);
//        $rec->castkaDPH->setNewValue($castkaDPH);
//        $rec->popis ->setNewValue($_POST['popis']);
//        $rec->datum ->setNewValue($datum);
//        $rec->typ ->setNewValue($_POST['typ']);
//        $rec->zpusobPlatby ->setNewValue((int)$_POST['zpusobplatby']);
//
//        if (RonPortalSettings::getIntValue('typrozdelenipoklk')) {
//            $rozdeleni = (isset($_POST['rozdeleni'])  &&  $_POST['rozdeleni'] != '') ?  $_POST['rozdeleni'] : null;
//            $rec ->kodTypuRozdeleni ->setNewValue($rozdeleni ? RonPortalSettings::getIntValue('typrozdelenipoklk') : null);
//            $rec ->rozdeleni ->setNewValue($rozdeleni ?: null);
//        }
//        if (RonPortalSettings::getIntValue('typrozdelenipoklk2')) {
//            $rozdeleni = (isset($_POST['rozdeleni2'])  &&  $_POST['rozdeleni2'] != '') ?  $_POST['rozdeleni2'] : null;
//            $rec ->kodTypuRozdeleni2 ->setNewValue($rozdeleni ? RonPortalSettings::getIntValue('typrozdelenipoklk2') : null);
//            $rec ->rozdeleni2 ->setNewValue($rozdeleni ?: null);
//        }
//        if (RonPortalSettings::getIntValue('typrozdelenipoklk3')) {
//            $rozdeleni = (isset($_POST['rozdeleni3'])  &&  $_POST['rozdeleni3'] != '') ?  $_POST['rozdeleni3'] : null;
//            $rec ->kodTypuRozdeleni3 ->setNewValue($rozdeleni ? RonPortalSettings::getIntValue('typrozdelenipoklk3') : null);
//            $rec ->rozdeleni3 ->setNewValue($rozdeleni ?: null);
//        }
//
//        return true;
//    }
//
//    /**
//     * @param Database $database
//     * @param SeznamPolozekPokladniKnihy $seznamPolozek
//     * @param string $logDescription
//     * @return bool
//     * @throws Exception
//     */
//    public static function ulozRadek($database, $seznamPolozek, $logDescription)
//    {
//
//        $rec = new RadekPokladniKnihyRecord($database, (int)$_POST['PokladniKniha_ID'], (int)$_POST['CisloRadku'], $seznamPolozek, $logDescription);
//
//        if ( !self::loadPostToRecord($rec) ) {
//            return false;
//        }
//
//        if (!$rec ->loadRecord()) {
//            throw new Exception('Chyba pri aktualizaci radku pokladni knihy - radek nebyl nalezen!');
//        }
//
//        $rec ->updateRecord();
//        return true;
//    }
//
//    /**
//     * @param Database $database
//     * @param SeznamPolozekPokladniKnihy $seznamPolozek
//     * @param string $logDescription
//     * @return bool
//     * @throws Exception
//     */
//    public static function vlozNovyRadek($database, $seznamPolozek, $logDescription)
//    {
//
//        $rec = new RadekPokladniKnihyRecord($database, (int)$_POST['PokladniKniha_ID'], null, $seznamPolozek, $logDescription);
//
//        if ( !self::loadPostToRecord($rec) ) {
//            return false;
//        }
//
//        $rec ->cisloRadku ->setNewValue( SQLUtils::newSerialNumber($database, 'RadekPokladniKnihy', 'CisloRadku', 'IDPokladniKnihy = ' . $_POST['PokladniKniha_ID']) );
//
//        $rec ->insertRecord();
//        return true;
//    }
//
//    /**
//     * @param Database $database
//     * @param PokladniKniha $pokladniKniha
//     * @param int $cisloRadku
//     * @param string $logDescription
//     * @throws Exception
//     */
//    public static function zrusRadek($database, $pokladniKniha, $cisloRadku, $logDescription)
//    {
//        $rec = new RadekPokladniKnihyRecord($database, $pokladniKniha->vratID(), (int)$cisloRadku, null, $logDescription);
//        if ($rec->loadRecord()) {
//
//
//            $rec ->doDelete('');
//
//            MessageManager::addInfoMessage(TextManager::_('PoklK_Zruseni_radku_OK'));
//            return;
//        }
//
//        throw new DBException($database, null, 'Pri mazani radku pokladni knihy doslo k chybe!');
//    }

}