<?php
/**
 * stanislav.elbl, 01.08.2021 12:04
 * Seznam planovanych skoleni (tabulka PlanovaneSkoleni)
 * Ridi se pravem skoleni_plan
 */

namespace RonPortal\Skoleni;

use Ron\Controls\BrowserField;
use Ron\DB\Database;
use Ron\DB\DBException;
use Ron\DB\SqlStatement;
use Ron\TextManager;
use RonPortal\Controls\RonPortalBrowser;
use RonPortal\NeniPravoException;
use RonPortal\Prava;
use RonPortal\PravaNaOsoby;

///**
// * Class PlanovaneSkoleniFilterForm
// */
//class PlanovaneSkoleniFilterForm extends SkoleniFilterForm
//{
//
////    /** @var PravaNaOsoby $prava*/
////    var $pravoNaPlan;
//
//    /**
//     * PlanovaneSkoleniFilterForm constructor.
//     * @param Database $database
//     */
//    public function __construct(Database $database)
//    {
//        parent::__construct($database, ['menuid' => 'skoleni', 'action' => 'planovaneskolenikurzy'], true);
//
//        $this->nastavDatumOdDo(true, false); // povinne = false
//        Prava::nastavObdobiProPrava(time(),time());
//
//        $this ->addDruhSkoleniFilter();
//    }
//
//
//    function loadData()
//    {
//        $this->loadDruhSkoleni();
//        parent::loadData();
//    }
//
//
//    /**
//     * @throws DBException
//     */
//    function renderFilters()
//    {
//        parent::renderFilters();
//        $this->renderDruhSkoleni();
//    }
//}

///**
// * Class DetailPlanovanehoSkolenikurzu
// * @package Ron\RonPortal
// */
//class DetailPlanovanehoSkolenikurzu extends BrowserField
//{
//
//    /**
//     * DetailPlanovanehoSkolenikurzu constructor.
//     * @param Database $database
//     */
//    function __construct($database)
//    {
//        parent::__construct($database);
//        $this->header = TextManager::_('detail_planovaneho_skoleni');
//    }
//
//    function getViewText($value, $rowNumber, $recordId, $rowData)
//    {
//        $result = '';
//        $result .= '<a href="?menuid=skoleni&action=detailplanovanehoskolenikurzu&record=' . HttpUtils::urlEncode($rowData[0]) . '">';
//        $result .= StringUtils::htmlTextConvert($rowData[1]);
//        $result .= '</a>';
//        return $result;
//    }
//}



/**
 * Class PlanovaneSkoleniBrowser
 */
class PlanovaneSkoleniBrowser extends RonPortalBrowser
{
    /** @var PravaNaOsoby $pravo*/
    public $pravo;


    /**
     * PlanovaneSkoleniBrowser constructor.
     * @param Database $database
     * @throws \Exception
     */
    public function __construct(Database $database)
    {
        parent::__construct($database, 'skoleni');

        Prava::nastavObdobiProPrava(time(), time());
        $this->pravo = Prava::vratPrava('skoleni_plan');
        if (!$this ->pravo ->jsouNejakePrava()) {
            throw new NeniPravoException();
        }

        $this->code = 'browserplanovaneskoleni';
        $this->tableId = 'browserplanovaneskoleni';
        $this->browserUrl = "?menuid=skoleni&action=planovaneskolenikurzy";

        $this->sqlSelectPart = 'PS.CisloSkoleni'; // 0

        $this->sqlFromPart =
            'PlanovaneSkoleni PS' .
            ' INNER JOIN DruhSkoleni ON DruhSkoleni.Kod = PS.DruhSkoleni' .
            ' LEFT JOIN S_StavPlanovanehoSkoleni ON PS.Stav = S_StavPlanovanehoSkoleni.Kod' .
            ' LEFT JOIN Firma ON PS.SkoliciFirma = Firma.kodFirmy';

        $this ->primaryField = 0;

        $this->addField()
            ->setSqlFieldName('PS.CisloSkoleni', 0) ->setHeaderText('ID') ->setOrdering(true)
            ->setCode('col-cisloskoleni');

        $this->addField()
            ->setSqlFieldName('PS.Popis') ->setHeaderText('detail_planovaneho_skoleni') ->setOrdering(true)
            ->setLink('?menuid=skoleni&action=planovaneskolenikurzy&formaction=edit&record=')
            ->setCode('col-popis');


        $this->addField(BrowserField::FIELD_TYPE_HIDDEN)
            ->setSqlFieldName('DruhSkoleni.Popis')
            ->setCode('col-popis-druhu-skoleni');

        $this->addField()
            ->setSqlFieldName('PS.DruhSkoleni') ->setHeaderText('druh_skoleni') ->setOrdering(true)
            ->setCode('col-druhskoleni')
            ->setTitleFieldIndex('col-popis-druhu-skoleni');


        $this->addField()
            ->setSqlFieldName('S_StavPlanovanehoSkoleni.Popis') ->setHeaderText('Stav') ->setOrdering(true)
            ->setCode('col-stav');

        $this->addField()
            ->setSqlFieldName('PS.DatumPocatkuSkoleni') ->setFormat('date') ->setHeaderText('datum_pocatku_skoleni') ->setOrdering(true)
            ->setCode('col-datumpocatkuskoleni')
            ->setAlign('center');

        $this->addField()
            ->setSqlFieldName('PS.CasPocatkuSkoleni') ->setFormat('time') ->setHeaderText('cas_pocatku_skoleni') ->setOrdering(true)
            ->setCode('col-caspocatkuskoleni')
            ->setAlign('center');

        $this->addField()
            ->setSqlFieldName('PS.CasUkonceniSkoleni') ->setFormat('time') ->setHeaderText('cas_ukonceni_skoleni') ->setOrdering(true)
            ->setCode('col-casukonceniskoleni')
            ->setAlign('center');

        $this->addField()
            ->setSqlFieldName('PS.DatumUkonceniSkoleni') ->setFormat('date') ->setHeaderText('datum_ukonceni_skoleni') ->setOrdering(true)
            ->setCode('col-datumukonceniskoleni')
            ->setAlign('center');

        $this->addField()
            ->setSqlFieldName('Firma.Nazev1') ->setHeaderText('skolici_firma') ->setOrdering(true)
            ->setCode('col-firma');

        $this->addField()
            ->setSqlFieldName('PS.Skolitel') ->setHeaderText('skolitel') ->setOrdering(true)
            ->setCode('col-skolitel');

        $this ->addField(BrowserField::FIELD_TYPE_HIDDEN)
            ->setSqlFieldName('PS.Insert_UserName')
            ->setCode('col-insert_username');

        $this ->addField()
            ->setSqlFieldName('PS.Insert_Timestamp') ->setSqlFieldIndex2('col-insert_username') ->setFormat('date')
            ->setHeaderText('datum_vlozeni') ->setAlign('center') ->setOrdering(true)
            ->setCode('col-datumvlozeni');


        $this ->addField(BrowserField::FIELD_TYPE_HIDDEN)
            ->setSqlFieldName('PS.Update_UserName')
            ->setCode('col-update_username');

        $this ->addField()
            ->setSqlFieldName('PS.Update_Timestamp') ->setSqlFieldIndex2('col-update_username') ->setFormat('date')
            ->setHeaderText('posledni_aktualizace') ->setAlign('center') ->setOrdering(true)
            ->setCode('col-datumaktualizace');
    }


    function setFilterForm()
    {
        Prava::nastavObdobiProPrava(time(),time());

        //$this->filterForm = new PlanovaneSkoleniFilterForm($this ->database);
        $this->filterForm = new SkoleniFilterForm($this ->database, ['menuid' => 'skoleni', 'action' => 'planovaneskolenikurzy'], true);
        $this->filterForm ->nastavDatumOdDo(true, false); // povinne = false
        $this->filterForm->addDruhSkoleniFilter();
    }


//    /**
//     * @param array $values
//     * @return bool
//     * @throws \Exception
//     */
//    function enableLine($values)
//    {
//        if ($this->pravo->prava == 3){
//            return true;
//        }
//
//        //30 bylo toto: "(SELECT RC FROM PlanovaneSkoleniOsob WHERE DatumVlozeni = (SELECT MIN(DatumVlozeni) FROM PlanovaneSkoleniOsob WHERE (PS.CisloSkoleni = PlanovaneSkoleniOsob.CisloSkoleni))) ";
//        //  - nesmysl - zruseno (kdyz budou 2 zaznamy se stejnym datem vlozeni, tak to zdechne)
//        if ($values[30] && $this->pravo->lzeZobrazitRC($values[30])) {
//            return true;
//        }
//
//        return false;
//    }


    /**
     * @return string
     */
    function getSQLFilter()
    {
        $params = $this->database->createParameters();
        $result = $this ->filterForm ->buildSqlFilter($params);

//        $result .= "PS.Stav < 2 ";    - Nebylo mozno zobrazit omylem zamitnute kurzy

        if ($this ->filterForm ->getFilterValue('druhskoleni')) {
            $result .=
                ($result ? ' AND ' : '') .
                'PS.DruhSkoleni = ' . $params->addParameter($this ->filterForm ->getFilterValue('druhskoleni'));
        }

        if ($this ->filterForm ->filtrovatDatum) {
            $result .=
                ($result ? ' AND ' : '') .
                ' PS.DatumPocatkuSkoleni >= ' . $params->addDateParameter($this ->filterForm ->datumOd) .
                ' AND PS.DatumPocatkuSkoleni <= ' . $params->addDateParameter($this ->filterForm ->datumDo);
        }

        return new SqlStatement($result, $params);
    }


    function renderFilter()
    {
        parent::renderFilter();

        echo
            '<div class="margin-top-2">' .
            '<a href="?menuid=skoleni&action=planovaneskolenikurzy&formaction=new">' . TextManager::_('MI_Zadat_novy_plan_kurzu') . '</a>' .
            '</div>';
    }


}
