<?php
/**
 * Seznam radku sluzebni cesty
 */

namespace RonPortal\SluzebniCesty;

use Ron\Controls\BrowserField;
use Ron\DateUtils;
use Ron\DB\Database;
use Ron\GuiUtils;
use Ron\Http\Csrf;
use Ron\StringUtils;
use Ron\TextManager;
use RonPortal\Controls\RonPortalBrowser;


class EditaceRSCField extends BrowserField
{
    protected $lzeEditovat;

    public function __construct($lzeEditovat)
    {
        parent::__construct();
        $this ->lzeEditovat = $lzeEditovat;
    }


    function getViewText($value, $rowNumber, $recordId, $rowData)
    {
        return
            '<a href="#" title="' . TextManager::_($this ->lzeEditovat ? 'Editovat_zaznam' : 'Detail') . '">' .
            '<i class="inline-glyph glyph-button fa ' . ($this ->lzeEditovat ? 'glyph-edit' : 'glyph-detail') . ' open-dialog"' .
            ' data-dialog="#radek_sc_dialog" data-ronform-url="?menuid=sluzebnicestyjs&action=radeksc&idsc=' . $rowData[0] . '&record="' . // id SC
            ' data-ronform-record="' . $rowData[1] . '">' . // id radku
            '</a>';
    }
}


class KopieRSCField extends BrowserField
{
    function getViewText($value, $rowNumber, $recordId, $rowData)
    {
        return
            '<a href="#" title="' . TextManager::_('Kopirovat_zaznam') . '">' .
            '<i class="inline-glyph glyph-button fa glyph-copy open-dialog"' .
            ' data-dialog="#radek_sc_dialog" data-ronform-url="?menuid=sluzebnicestyjs&action=radeksc&idsc=' . $rowData[0] . '&record=' . $rowData[1] . '">' . // id SC
            '</a>';
    }
}


class ZruseniRSCField extends BrowserField
{
    function getViewText($value, $rowNumber, $recordId, $rowData)
    {
        /** @noinspection HtmlUnknownTarget */
        return GuiUtils::changeLocationQuest(
            '<i class="inline-glyph glyph-button fa glyph-delete" title="' . TextManager::_('Zrusit_zaznam') . '"></i>',
            TextManager::_('SC_Opravdu_zrusit_radek'),
            '?menuid=sluzebnicesty&action=zrusitradeksluzebky&record=' . $rowData[0] . '&radek='. $rowData[1] . Csrf::csrfUrlParameter("deleteradeksc-{$rowData[0]}-{$rowData[1]}"),
            'data-ron-send-position="1"'
        );
    }
}



class RadekSluzebniCestyBrowser extends RonPortalBrowser
{
//    var $editovatRadek;
//    var $kopirovatRadek; // cislo radku, ktery se ma kopirovat
    /** @var SluzebniCesta */
    var $sluzebniCesta;
//    var $zobrazitNovyRadek;
    var $lzeEditovat;

    var $vychoziDatum;
    var $vychoziCas;
    var $vychoziStat;

    var $zobrazitMisto; // zobrazuje se jen kdyz nejake existuje

    private $posledniDatum = null;


    /**
     * @param Database $database
     * @param bool $lzeEditovat
     * @param SluzebniCesta $sluzebniCesta
     * @param string $akce
     */
    function __construct($database, $lzeEditovat, $sluzebniCesta, $akce)
    {
        parent::__construct($database, null);

        $this->sluzebniCesta = $sluzebniCesta;
        $this->code = 'browserradeksc';

        $this->title = TextManager::_('Seznam_radku_sc');
        $this->tableId = 'tblRadekSluzebniCesty';
        $this ->sqlSelectPart =
            'RadekSluzebniCesty.SluzebniCesta_ID, RadekSluzebniCesty.CisloRadku, RadekSluzebniCesty.DatumCasOd, RadekSluzebniCesty.Poznamka'; // 0..3

        $this->sqlFromPart =
            '( RadekSluzebniCesty LEFT OUTER JOIN OperaceDochazky ' .
            '  ON RadekSluzebniCesty.KodOperace = OperaceDochazky.Kod ' .
            ') ' .
            ' INNER JOIN Stat ON RadekSluzebniCesty.Stat = Stat.Kod' .
            ' LEFT OUTER JOIN MistoSluzebniCesty ON MistoSluzebniCesty.Kod = RadekSluzebniCesty.Misto' .
            ' LEFT OUTER JOIN DopravniProstredek ON RadekSluzebniCesty.DopravniProstredek = DopravniProstredek.Kod';

        $this->sqlWherePart =
            'RadekSluzebniCesty.SluzebniCesta_ID = ' . (int)$sluzebniCesta ->id;

        $this->defaultSort = 'col-datum';
        $this->primaryField = 1;

        $this->lzeEditovat = $lzeEditovat;

        $this->showMessages = $this ->code; // jen zpravy prirazene browseru

        $this->cssClass = 'browser minwidth';

        $this ->zobrazitMisto = false;

        $cursor = $database ->getSqlResult('SELECT COUNT(*) FROM MistoSluzebniCesty WHERE Aktivni = 1');
        if ($row = $cursor ->fetch()) {
            if ($row[0]) {
                $this ->zobrazitMisto = true;
            }
        }

        $this->addField()
            ->setSqlFieldName('RadekSluzebniCesty.DatumCasOd', 2)
            ->setCode('col-datum') ->setHeaderText('Date') ->setFormat('date');

        $this->addField()
            ->setSqlFieldName('RadekSluzebniCesty.DatumCasOd', 2)
            ->setCode('col-cas') ->setHeaderText('Cas') ->setFormat('time');

        // kod operace pro pripadny preklad v nasledujicim poli
        $this->addField(BrowserField::FIELD_TYPE_HIDDEN)
            ->setSqlFieldName('RadekSluzebniCesty.KodOperace')
            ->setCode('col-kodoperace');

        $this->addField()
            ->setSqlFieldName('OperaceDochazky.Popis') ->setClassName('radekSC_operace')
            ->setCode('col-operace') ->setHeaderText('Operace_sc') ->setVisible(SluzebniCestyController::getZobrazitOperaceSC())
            ->setTranslationPrefix('db_operacedochazky_popis_', 'col-kodoperace');

        // kod mista SC pro pripadny preklad v nasledujicim poli
        $this->addField(BrowserField::FIELD_TYPE_HIDDEN)
            ->setSqlFieldName('RadekSluzebniCesty.Misto')
            ->setCode('col-kodmista');

        $this->addField()
            ->setSqlFieldName('MistoSluzebniCesty.Popis') ->setClassName('radekSC_misto')
            ->setCode('col-misto') ->setHeaderText('Misto_sc') ->setVisible($this ->zobrazitMisto) // zobrazuje se jen kdyz jsou nejaka mista v databazi
            ->setTranslationPrefix('db_mistosluzebnicesty_popis_', 'col-kodmista');

        $this->addField()
            ->setSqlFieldName('RadekSluzebniCesty.Popis')
            ->setCode('col-popis') ->setHeaderText('Popis_radku_sc') ->setClassName('radekSC_popis');

        // kod statu - pro preklad v poli stat
        $this->addField(BrowserField::FIELD_TYPE_HIDDEN)
            ->setSqlFieldName('RadekSluzebniCesty.Stat')
            ->setCode('col-kodstatu');

        $this->addField()
            ->setSqlFieldName('Stat.Popis')
            ->setCode('col-stat') ->setHeaderText('Stat') ->setClassName('radekSC_stat')
            ->setTranslationPrefix('db_stat_popis_', 'col-kodstatu');


        // kod dopravniho prostredku pro pripadny preklad v nasledujicim poli
        $this->addField(BrowserField::FIELD_TYPE_HIDDEN)
            ->setSqlFieldName('RadekSluzebniCesty.DopravniProstredek')
            ->setCode('col-koddopravnihoprostredku');

        $this->addField()
            ->setSqlFieldName('DopravniProstredek.Popis')
            ->setCode('col-dopravniprostredek') ->setHeaderText('Dopravni_prostredek')
            ->setVisible(false)
            ->setTranslationPrefix('db_dopravniprostredek_popis_', 'col-koddopravnihoprostredku');

        $this->addField()
            ->setSqlFieldName('PocetPJidel_S')
            ->setCode('col-snidane') ->setHeaderText('Pocet_snidani') ->setAlign('right') ->setClassName('radekSC_snidane')
        ;
        $this->addField()
            ->setSqlFieldName('PocetPJidel_O')
            ->setCode('col-obedy') ->setHeaderText('Pocet_obedu') ->setAlign('right') ->setClassName('radekSC_obed');

        $this->addField()
            ->setSqlFieldName('PocetPJidel_V')
            ->setCode('col-vecere') ->setHeaderText('Pocet_veceri') ->setAlign('right') ->setClassName('radekSC_vecere');

        if ($lzeEditovat) {
            // TODO: aby slo zobrazit i detail pro needitovatelne radky, je potreba vylepsit podporu readonly zobrazeni v dialogu!
            $this->addField(new EditaceRSCField($lzeEditovat))
                ->setAlign('left')->setCode('col-edit');
        }

        if ($lzeEditovat) {
            $this->addField(new KopieRSCField())
                ->setAlign('left') ->setCode('col-copy');

            $this->addField(new ZruseniRSCField())
                ->setAlign('left') ->setCode('col-delete');
        }

       // $this ->loadConfigurationXml(RonPortalBrowser::loadBrowserConfiguration($this ->database, $this ->code));
    }

    function setFilterForm()
    {
        // nedela nic - filter form se nepouziva
    }




//    function renderFieldEdit($index, $field, $value, $rowNumber, $recordId, $values)
//    {
//        switch ($field->sqlFieldName) {
//            case 'RadekSluzebniCesty.DatumCasOd' :
//                // pole pro datum nebo pro cas (rozlisi se podle formatu)
//                if ($field->format == 'date') {
//                    if (isset($_POST['DatumOd'])) $value = StringUtils::htmlTextConvert($_POST['DatumOd']);
//                    else if ($value) $value = DBUtils::getFormatedValue($this ->database, $field->format, $value);
//                    else $value = StringUtils::format($field->format, $this->vychoziDatum);
//
//                    echo
//                        '<td style="white-space:nowrap">' .
//
//                        '<div class="input-group">' .
//                        '<input type="text" name="DatumOd" class="form-control input-date inputDate ' . MessageManager::getClass('DatumOd') . '" value="' . $value . '" maxlength="10" size="10">' .
//                        '<i class="showcalendar input-group-text fa glyph-calendar"  data-roncalendar-inputname="DatumOd"></i>' .
//                        '</div>' .
//
//                        '<input type="hidden" name="SluzebniCesta_ID" value="' . $this->sluzebniCesta ->id . '">' .
//                        '<input type="hidden" name="CisloRadku" value="' . (isset($values[1]) ? $values[1] : '') . '">' .
//                        '<input type="hidden" name="EditaceRadkuSC" value="1">' .
//
//                        '</td>';
//                } else {
//                    $value = (isset($_POST['CasOd']))
//                        ? StringUtils::htmlTextConvert($_POST['CasOd'])
//                        : DBUtils::getFormatedValue($this ->database, $field->format, $value);
//                    echo '<TD><INPUT type="text" name="CasOd" class="form-input ' . MessageManager::getClass('CasOd') . '" value="' . $value . '" maxlength="5" size="5"></TD>';
//                }
//                break;
//
//            case 'OperaceDochazky.Popis' :
//                echo '<TD class="radekSC_operace">';
//                $value = isset($_POST['KodOperace'])
//                    ? $_POST['KodOperace']
//                    : ($values ? $values[2] : null);
//
//                $combo = new ComboBox('KodOperace');
//                $combo ->emptyRow = ' ';
//                $combo ->loadData($this ->database,
//                    'SELECT Kod, Popis FROM OperaceDochazky WHERE ' . ($this ->sluzebniCesta ->zahranicni ? 'UdalostZahranicniSC' : 'UdalostSluzebniCesty') . ' = 1 ORDER BY Popis',
//                    $value);
//                $combo ->render();
//                echo '</TD>';
//                break;
//
//            //case 'RadekSluzebniCesty.Misto' :
//            case 'MistoSluzebniCesty.Popis' :
//                echo '<TD class="radekSC_misto">';
//                $value = isset($_POST['Misto'])
//                    ? $_POST['Misto']
//                    : (isset($values[11]) ? $values[11] : null);
//
//                $combo = new ComboBox('Misto');
//                $combo ->emptyRow = ' ';
//                $combo ->loadData($this ->database,
//                    'SELECT Kod, Popis FROM MistoSluzebniCesty WHERE Aktivni = 1 ORDER BY Popis',
//                    $value);
//                $combo ->render();
//                echo '</TD>';
//                break;
//
//            case 'RadekSluzebniCesty.Popis' :
//                if (isset($_POST['Popis'])) $value = $_POST['Popis'];
//
//                echo '<td class="radekSC_popis"><input type="text" name="Popis" class="form-input" value="' . StringUtils::htmlTextConvert($value) . '" size="40" maxlength="160"/></td>';
//                break;
//
//            case 'Stat.Popis' :
//                echo '<TD class="radekSC_stat">';
//
//                if (isset($_POST['Stat'])) {
//                    $value = $_POST['Stat'];
//                } else {
//                    $value = (isset($values[3])  && $values[3])
//                        ? $values[3]
//                        : $this->vychoziStat;
//                }
//
//                $combo = new ComboBox('Stat');
//                $combo ->loadData($this ->database,
//                    'SELECT Kod, Popis FROM Stat WHERE PovolitVeSluzCeste = 1 ORDER BY Popis', $value);
//                $combo ->className = 'form-input ronselect';
//                $combo ->render();
//
//                echo '</TD>';
//                break;
//
//            case 'PocetPJidel_S' :
//            case 'PocetPJidel_O' :
//            case 'PocetPJidel_V' :
//                if (isset($_POST[$field->sqlFieldName])) $value = $_POST[$field->sqlFieldName];
//                echo '<TD class="' . $field ->className . '"><INPUT type="text" class="form-input" name="' . $field->sqlFieldName . '" value="' . (int)$value . '" size="2" maxlength="2"></TD>';
//                break;
//        }
//    }


    // Zobrazeni jednoho radku
    function renderLine($values, $className, $rowNumber, $edit = false)
    {
//        $edit = $values
//            ? $this->editovatRadek == $values[1]
//            : true; // novy radek

        $date = DateUtils::startOfTheDay($this ->database ->stringToTimestamp($values['col-datum']));
        $newDate = $date  &&  $this ->posledniDatum  &&  $this ->posledniDatum !== $date;
        $this ->posledniDatum = $date;

        parent::renderLine($values, $className . ($newDate ? ' border-top border-dark' : ''), $rowNumber, $edit);

        $poznamkaStr = ($values && $values[3]) ? $values[3] : '';

//        if ($edit) {
//            if (isset($_POST['Poznamka'])) $poznamkaStr = $_POST['Poznamka'];
//            echo
//                "<tr class='$className poznamkaRadkuSC'>" .
//                "<td class='align-right'>" . TextManager::_('Poznamka') ."</td>" .
//                "<td colspan='" . (count($this ->fields) - 1) . "'><input name='Poznamka' class='poznamkaRadkuSC' maxlength='250' value='" . StringUtils::htmlTextConvert($poznamkaStr) . "'></td>" .
//                "</tr>\n";
//        } else
        if ($poznamkaStr) {
            echo
                "<tr class='$className poznamkaRadkuSC'>" .
                "<td></td><td class='poznamka browserpoznamka' colspan='" . (count($this ->fields) - 1) . "'>" . StringUtils::htmlTextConvert($poznamkaStr) . "</td>" .
                "</tr>\n";
        }

//        if ($values && $this->kopirovatRadek == $values[1]) {
//            $values[1] = null;
//            $this->renderLine($values, '', 0, true);
//        }
    }




//    function nactiHodnotyProNovyRadek()
//    {
//        $sql =
//            'SELECT SluzebniCesta.DatumCasOd, DatumCasDo, SluzebniCesta.Stat, MAX(RadekSluzebniCesty.DatumCasOd)' .
//            '  FROM SluzebniCesta LEFT OUTER JOIN RadekSluzebniCesty ON RadekSluzebniCesty.SluzebniCesta_ID = SluzebniCesta.Id ' .
//            ' WHERE SluzebniCesta.Id = ' . (int)$this->sluzebniCesta ->id .
//            ' GROUP BY SluzebniCesta.DatumCasOd, DatumCasDo, SluzebniCesta.Stat ';
//
//        $cursor = $this ->database ->getSqlResult($sql);
//
//        if ($row = $cursor ->fetch()) {
//            if ($row[3]) {
//                // nejedna se o prvni radek - datum podle posledniho zaznamu, cas nevyplneny
//                $this->vychoziCas = '';
//                $this->vychoziDatum = $cursor ->stringToTimestamp($row[3]);
//            } else {
//                // jedna se o prvni radek - datum a cas podle zacatku sl. cesty
//                $this->vychoziCas = $cursor ->stringToTimestamp($row[0]);
//                $this->vychoziDatum = $this->vychoziCas;
//            }
//
//            $this->vychoziStat = $row[2];
//        }
//    }


//    function renderData() // , $firstRow)
//    {
//        parent::renderData();
//
//        // prida navic jeden novy radek pro editaci
//        if ($this->zobrazitNovyRadek) {
//            $this->nactiHodnotyProNovyRadek();
//            $this ->renderLine(null, '', 0, true); // edit = true
//        }
//    }


//    /**
//     * @param Database $database
//     * @param int $idSluzebniCesty
//     * @param int $cisloRadku
//     * @return bool
//     */
//    public static function zrusRadekSluzebniCesty($database, $idSluzebniCesty, $cisloRadku, $logDescription)
//    {
//        $rec = new RadekSCDBRecord($database, $idSluzebniCesty, $logDescription, $cisloRadku);
//
//        try {
//            $rec->deleteRecord();
//            MessageManager::addInfoMessage( TextManager::_('SC_Zruseni_radku_OK') );
//            return true;
//        } catch (\Exception $e) {
//            MessageManager::addErrorMessage($e ->getMessage());
//            return false;
//        }
//    }

//    /**
//     * @param RadekSCDBRecord $rec
//     * @param SluzebniCesta $sluzebniCesta
//     * @throws \Exception
//     */
//    private static function loadPost($rec, $sluzebniCesta)
//    {
//        try {
//            $datum = DateUtils::dateStringToTimestamp($_POST['DatumOd']);
//        } catch (\Exception $e) {
//            throw new RonException($e ->getMessage(), 'DatumOd');
//        }
//        try {
//            $cas = DateUtils::timeStringToTimestamp($_POST['CasOd'], $datum);
//        } catch (\Exception $e) {
//            throw new RonException($e ->getMessage(), 'CasOd');
//        }
//
//
//        if (!$sluzebniCesta ->pocatekKonecPodleRadku) {
//            // Kontrola, jestli je zadany cas v rozsahu casu sluzebni cesty
//            if (RonPortalSettings::getIntValue(SluzebniCesta::SETTINGS_CASY_AUTOMATICKY)) {
//                // cas pocatku a konce se nastavuje automaticky - kontroluje jenom datum
//                if ($cas < DateUtils::startOfTheDay($sluzebniCesta->datumCasOd) || $cas > DateUtils::endOfTheDay($sluzebniCesta->datumCasDo)) {
//                    throw new \Exception(TextManager::_('Datum_mimo_rozsah_sc') . ' ' .
//                        date('j.n.Y', $sluzebniCesta->datumCasOd) . ' - ' . date('j.n.Y', $sluzebniCesta->datumCasDo));
//                }
//            } else {
//                if ($cas < $sluzebniCesta->datumCasOd || $cas > $sluzebniCesta->datumCasDo) {
//                    throw new \Exception(
//                        TextManager::_('Cas_mimo_rozsah_sc') . ' ' .
//                        date('j.n.Y G:i', $sluzebniCesta->datumCasOd) . ' - ' . date('j.n.Y G:i', $sluzebniCesta->datumCasDo));
//                }
//            }
//        }
//
//        if ( SluzebniCestyController::getZobrazitOperaceSC() ) {
//            if ( !$_POST['KodOperace'] ) {
//                throw new \Exception(TextManager::_('Nutno_zadat_operaci'));
//            }
//
//            $rec->fKodOperace ->setNewValue($_POST['KodOperace']);
//        }
//
//        if (!$_POST['Stat']) {
//            throw new \Exception( TextManager::_('Neni_zadan_stat') );
//        }
//
//        $rec->fPopis ->setNewValue($_POST['Popis']);
//        if (isset($_POST['Misto'])) {
//            $rec->fMisto->setNewValue($_POST['Misto'] ?: null);
//        }
//        $rec->fStat ->setNewValue($_POST['Stat']);
//
//        $rec->fDatumCasOd ->setNewValue($cas);
//
//        $rec->fPocetPJidel_S ->setNewValue((int)$_POST['PocetPJidel_S']);
//        $rec->fPocetPJidel_O ->setNewValue((int)$_POST['PocetPJidel_O']);
//        $rec->fPocetPJidel_V ->setNewValue((int)$_POST['PocetPJidel_V']);
//
//        $rec->fPoznamka ->setNewValue($_POST['Poznamka']);
//    }
//
//    /**
//     * @param Database $database
//     * @param SluzebniCesta $sluzebniCesta
//     * @param $logDescription
//     * @return bool|int
//     * @throws \Exception
//     */
//    public static function ulozRadekSluzebniCesty($database, $sluzebniCesta, $logDescription)
//    {
//        $rec = new RadekSCDBRecord($database, $sluzebniCesta ->id, $logDescription, (int)$_POST['CisloRadku']);
//        self::loadPost($rec, $sluzebniCesta);
//
//        if (!$rec->loadRecord()) {
//            throw new \Exception('Chyba! Editovany radek nebyl nalezen!');
//        }
//
//        if ( !$rec->updateRecord() ) {
//            return false;
//        }
//
//        if ( RonPortalSettings::getIntValue(SluzebniCesta::SETTINGS_CASY_AUTOMATICKY) ) {
//            return $sluzebniCesta ->updateCasy($database);
//        }
//
//        return true;
//    }
//
//
//    /**
//     * @param Database $database
//     * @param SluzebniCesta $sluzebniCesta
//     * @param $logDescription
//     * @return bool
//     * @throws \Exception
//     */
//    public static function vlozNovyRadekSluzebniCesty($database, $sluzebniCesta, $logDescription)
//    {
//        $rec = new RadekSCDBRecord($database, $sluzebniCesta ->id, $logDescription);
//        self::loadPost($rec, $sluzebniCesta);
//
//        $rec ->insertRadek();
//
//        if ( RonPortalSettings::getIntValue(SluzebniCesta::SETTINGS_CASY_AUTOMATICKY) ) {
//            return $sluzebniCesta->updateCasy($database);
//        }
//
//        return true;
//    }


    /**
     * @param Database $database
     * @param SluzebniCesta $sluzebniCesta
     * @param bool   $lzeEditovat
     * @param string $akce
     */
    public static function zobrazRadkySluzebniCesty($database, $sluzebniCesta, $lzeEditovat, $akce)
    {
        $b = new static($database, $lzeEditovat, $sluzebniCesta, $akce);

//        $formaction = '';

//        if ($lzeEditovat) {
//            switch ($akce) {
//                case 'editovatradeksluzebky' :
//                    $formaction = 'ulozradeksluzebky';
//                    if (isset($_POST['CisloRadku'])) $b->editovatRadek = (int)$_POST['CisloRadku'];
//                    else $b->editovatRadek = (int)$_GET['radek'];
//                    break;
//
//                case 'kopirovatradeksluzebky' :
//                    $formaction = 'vlozradeksluzebky';
//                    $b->kopirovatRadek = $_GET['radek'];
//                    break;
//
//                case 'pridatradeksluzebky' :
//                    $formaction = 'vlozradeksluzebky';
//                    $b->zobrazitNovyRadek = true;
//                    break;
//            }
//        }

        $b ->load();

//        if ($formaction && $lzeEditovat) {
//            echo '<FORM class="sendPosition" method="post" action="?menuid=sluzebnicesty&action=' . $formaction . '">' . "\n";
//            echo '<INPUT type="hidden" name="x"><INPUT type="hidden" name="y">'; // pro zapamatovani scrollovani v prohlizeci
//            echo "\n";
//        }

        $b->render();

//        if ($formaction && $lzeEditovat) {
//            echo '<INPUT type="submit" class="submitbutton" value="' . TextManager::_('form.Store') . '">';
//
//            $href = '?menuid=sluzebnicesty&action=zobrazslcestu&record=' . $sluzebniCesta ->id;
//            echo '<INPUT type="button" class="button clickHref" value="' . TextManager::_('Cancel') . '" data-ron-href="' . $href . '" data-ron-send-position="1">';
//
//            echo "</FORM>\n";
//        }

        //if (!$formaction && $lzeEditovat) {
        if ($lzeEditovat) {
//            global $development;

            /** @noinspection HtmlUnknownAnchorTarget */
            echo
                "<div class='text_link' id='radekSCBrowserLinks'><ul class='linkslist'>\n" .
//                "<li><a class='sendPosition' href='?menuid=sluzebnicesty&action=pridatradeksluzebky&record={$sluzebniCesta ->id}'>" . TextManager::_('Novy_radek') . "</a></li>\n" .
                "<li><a href='#' class='open-dialog' data-dialog='#radek_sc_dialog'>" . TextManager::_('Novy_radek') . "</a></li>\n" .
                "<li><a href='?menuid=sluzebnicesty&action=editovatradkysluzebky&record={$sluzebniCesta ->id}'>" . TextManager::_('Editovat_radky_sc') . "</a></li>\n" .
                "</ul></div>\n";
        }

        //echo '<script>ron.sc.browserRadekSluzebniCesty()</script>';
    }

}
