<?php
/**
 * pavel.rudol, 18.8.2022 13:32
 */

namespace RonPortal\Vyroba;

use Ron\Controls\BrowserField;
use Ron\Controls\ComboBox;
use Ron\DB\SqlStatement;
use Ron\GuiUtils;
use Ron\TextManager;
use RonPortal\Controls\RonPortalBrowser;
use RonPortal\Controls\RonPortalFilterForm;

class CinnostiFilterForm extends RonPortalFilterForm
{
    public $typCinnosti;
    public $druhZpracovani;
    public $statusCinnosti;
    public $jenAktivni;

    private function loadTypCinnosti()
    {
        if (isset($_GET['typcinnosti'])) {
            $this ->typCinnosti = $_GET['typcinnosti'];
            if (trim($this ->typCinnosti === '')) {
                $this ->typCinnosti = null;
            }
            $_SESSION['typcinnosti'] = $this ->typCinnosti;
        } else {
            $this ->typCinnosti = $_SESSION['typcinnosti'] ?? null;
        }
    }

    private function loadDruhZpracovani()
    {
        if (isset($_GET['druhzpracovani'])) {
            $this ->druhZpracovani = $_GET['druhzpracovani'];
            if (trim($this ->druhZpracovani === '')) {
                $this ->druhZpracovani = null;
            }
            $_SESSION['druhzpracovani'] = $this ->druhZpracovani;
        } else {
            $this ->druhZpracovani = $_SESSION['druhzpracovani'] ?? null;
        }
    }

    private function loadStatusCinnosti()
    {
        if (isset($_GET['statuscinnosti'])) {
            $this ->statusCinnosti = $_GET['statuscinnosti'];
            if (trim($this ->statusCinnosti === '')) {
                $this ->statusCinnosti = null;
            }
            $_SESSION['statuscinnosti'] = $this ->statusCinnosti;
        } else {
            $this ->statusCinnosti = $_SESSION['statuscinnosti'] ?? null;
        }
    }

    private function loadAktivni()
    {
        if (isset($_GET['druhzpracovani'])) {
            $this ->jenAktivni = isset($_GET['aktivni']);
            if (!$this->jenAktivni) {
                $this->jenAktivni = null;
            }

            $_SESSION['aktivnicinnosti'] = $this ->jenAktivni;
        } else {
            $this ->jenAktivni = $_SESSION['aktivnicinnosti'] ?? true;
        }
    }

    public function loadData()
    {
        parent::loadData();
        $this->loadDruhZpracovani();
        $this->loadTypCinnosti();
        $this->loadStatusCinnosti();
        $this->loadAktivni();
    }

    private function renderFilterTyp()
    {
        echo "<div class='filterrow'>";

        echo "<span class='filtercaption'>";
        echo TextManager::_('Typ');
        echo "</span>";

        $params = $this->database->createParameters();
        $sql =
            'SELECT Kod, Popis FROM TypVyrobniCinnosti ORDER BY Popis';

        $combo = new ComboBox('typcinnosti');
        $combo->emptyRow = TextManager::_('_vse_');

        $combo->className = 'form-input adsfilterforminput_full ronselect';
        $combo->htmlParams = [
            'data-ronselect-class' => 'ronselect adsfilterforminput_full',
            'data-ron-autosubmit' => '1',
            'data-columns' => 'text'
        ];
        $combo->loadData($this ->database, $sql, $this ->typCinnosti, $params);
        $combo->render();

        echo "</div>";
    }

    private function renderFilterDruhZpracovani()
    {
        echo "<div class='filterrow'>";

        echo "<span class='filtercaption'>";
        echo TextManager::_('vyroba_druh_zpracovani');
        echo "</span>";

        $params = $this->database->createParameters();
        $sql =
            'SELECT Kod, Popis FROM S_DruhZpracovaniCinnosti ORDER BY Popis';

        $combo = new ComboBox('druhzpracovani');
        $combo->emptyRow = TextManager::_('_vse_');

        $combo->className = 'form-input adsfilterforminput_full ronselect';
        $combo->htmlParams = [
            'data-ronselect-class' => 'ronselect adsfilterforminput_full',
            'data-ron-autosubmit' => '1',
            'data-columns' => 'text'
        ];
        $combo->loadData($this ->database, $sql, $this ->druhZpracovani, $params);
        $combo->render();

        echo "</div>";
    }

    private function renderFilterStatusCinnosti()
    {
        echo "<div class='filterrow'>";

        echo "<span class='filtercaption'>";
        echo TextManager::_('vyroba_status_cinnosti');
        echo "</span>";

        $params = $this->database->createParameters();
        $sql =
            'SELECT Kod, Popis FROM StatusVyrobniCinnosti ORDER BY Popis';

        $combo = new ComboBox('statuscinnosti');
        $combo->emptyRow = TextManager::_('_vse_');

        $combo->className = 'form-input adsfilterforminput_full ronselect';
        $combo->htmlParams = [
            'data-ronselect-class' => 'ronselect adsfilterforminput_full',
            'data-ron-autosubmit' => '1',
            'data-columns' => 'text'
        ];
        $combo->loadData($this ->database, $sql, $this ->statusCinnosti, $params);
        $combo->render();

        echo "</div>";
    }

    private function renderFilterAktivni()
    {
        echo "<div class='filterrow'>";

        echo "<span class='filtercaption'>";
        echo "</span>";

        GuiUtils::renderCheckbox('aktivni', TextManager::_('Vyroba_jen_aktivni'), $this->jenAktivni, '', 'clickAutoSubmit');

        echo "</div>";
    }

    public function renderFilters()
    {
        parent::renderFilters();
        $this->renderFilterDruhZpracovani();
        $this->renderFilterTyp();
        $this->renderFilterStatusCinnosti();
        $this->renderFilterAktivni();

        echo "<a href='?menuid=vyrobnicinnosti&formaction=new'>" . TextManager::_('New_record') . "</a>";
    }

}

class VyrobniCinnostiBrowser extends RonPortalBrowser
{
    /** @var CinnostiFilterForm */
    public $filterForm;

    public function __construct($database)
    {
        parent::__construct($database, 'vyroba');
        $this->browserUrl = '?menuid=vyrobnicinnosti&';

        $this->title = TextManager::_('Vyroba_seznam_cinnosti');

        $this->code = 'browservyrobnicinnosti';

        $this->sqlFromPart =
            'VyrobniCinnost JOIN S_DruhZpracovaniCinnosti ON S_DruhZpracovaniCinnosti.Kod = VyrobniCinnost.DruhZpracovani ' .
            ' LEFT OUTER JOIN TypVyrobniCinnosti ON TypVyrobniCinnosti.Kod = VyrobniCinnost.Typ ' .
            ' LEFT OUTER JOIN StatusVyrobniCinnosti ON StatusVyrobniCinnosti.Kod = VyrobniCinnost.Status';

        $this->primaryField = 0;

        $this->maxPageRows = 100;

        $this->addField()
            ->setSqlFieldName('VyrobniCinnost.kod')->setHeaderText('Kod')
            ->setCode('col-kod')->setOrdering(true);
        $this->addField()
            ->setSqlFieldName('VyrobniCinnost.popis')->setHeaderText('Popis')->setLink('?menuid=vyrobnicinnosti&formaction=edit')
            ->setCode('col-popis')->setOrdering(true);
        $this->addField()
            ->setSqlFieldName('S_DruhZpracovaniCinnosti.Popis')->setHeaderText('vyroba_druh_zpracovani')
            ->setCode('col-druh-zpracovani')->setOrdering(true);
        $this->addField()
            ->setSqlFieldName('VyrobniCinnost.Aktivni')->setHeaderText('Vyroba_aktivni')
            ->setCode('col-aktivni')->setOrdering(true)->setFormat('anone');
        $this->addField()
            ->setSqlFieldName('TypVyrobniCinnosti.popis')->setHeaderText('vyroba_typ_cinnosti')
            ->setCode('col-typ-cinnosti')->setOrdering(true);
        $this->addField()
            ->setSqlFieldName('StatusVyrobniCinnosti.popis')->setHeaderText('vyroba_status_cinnosti')
            ->setCode('col-status-cinnosti')->setOrdering(true);
        $this->addField(BrowserField::FIELD_TYPE_COMMENT)
            ->setSqlFieldName('{fn_CASTWIDEMEMO(VyrobniCinnost.Poznamka)}')
            ->setHeaderColSpan(-1)
            ->setClassName('poznamka')
            ->setCode('col-poznamka');
    }

    function setFilterForm()
    {
        $this->filterForm = new CinnostiFilterForm($this->database, ['menuid' => 'vyrobnicinnosti'], true);
    }

    public function getSQLFilter()
    {
        $params = $this->database->createParameters();

        $filter = '';

        if (!is_null($this->filterForm->typCinnosti)) {
            $filter = 'Typ = ' . $params->addParameter($this->filterForm->typCinnosti);
        }

        if (!is_null($this->filterForm->druhZpracovani)) {
            if ($filter !== '') {
                $filter .= ' AND ';
            }
            $filter .= 'DruhZpracovani = ' . $params->addParameter($this->filterForm->druhZpracovani);
        }

        if (!is_null($this->filterForm->statusCinnosti)) {
            if ($filter !== '') {
                $filter .= ' AND ';
            }
            $filter .= 'Status = ' . $params->addParameter($this->filterForm->statusCinnosti);
        }

        if (!is_null($this->filterForm->jenAktivni)) {
            if ($filter !== '') {
                $filter .= ' AND ';
            }
            $filter .= 'Aktivni = 1';
        }

        return new SqlStatement($filter, $params);
    }


}